@@ -14,46 +14,44 @@
 """Availability Zone action implementations"""
 
 import copy
+import logging
 
 from novaclient import exceptions as nova_exceptions
-import six
+from osc_lib.command import command
+from osc_lib import utils
 
-from openstackclient.common import command
-from openstackclient.common import utils
-from openstackclient.i18n import _  # noqa
+from openstackclient.i18n import _
 
 
-def _xform_common_availability_zone(az, zone_info):
-    if hasattr(az, 'zoneState'):
-        zone_info['zone_status'] = ('available' if az.zoneState['available']
-                                    else 'not available')
-    if hasattr(az, 'zoneName'):
-        zone_info['zone_name'] = az.zoneName
-
-    zone_info['zone_resource'] = ''
+LOG = logging.getLogger(__name__)
 
 
 def _xform_compute_availability_zone(az, include_extra):
     result = []
-    zone_info = {}
-    _xform_common_availability_zone(az, zone_info)
+    zone_info = {
+        'zone_name': az.name,
+        'zone_status': (
+            'available' if az.state['available'] else 'not available'
+        ),
+    }
 
     if not include_extra:
         result.append(zone_info)
         return result
 
-    if hasattr(az, 'hosts') and az.hosts:
-        for host, services in six.iteritems(az.hosts):
+    if az.hosts:
+        for host, services in az.hosts.items():
             host_info = copy.deepcopy(zone_info)
             host_info['host_name'] = host
 
-            for svc, state in six.iteritems(services):
+            for svc, state in services.items():
                 info = copy.deepcopy(host_info)
                 info['service_name'] = svc
                 info['service_status'] = '%s %s %s' % (
                     'enabled' if state['active'] else 'disabled',
                     ':-)' if state['available'] else 'XXX',
-                    state['updated_at'])
+                    state['updated_at'],
+                )
                 result.append(info)
     else:
         zone_info['host_name'] = ''
@@ -65,8 +63,12 @@ def _xform_compute_availability_zone(az, include_extra):
 
 def _xform_volume_availability_zone(az):
     result = []
-    zone_info = {}
-    _xform_common_availability_zone(az, zone_info)
+    zone_info = {
+        'zone_name': az.name,
+        'zone_status': (
+            'available' if az.state['available'] else 'not available'
+        ),
+    }
     result.append(zone_info)
     return result
 
@@ -74,35 +76,38 @@ def _xform_volume_availability_zone(az):
 def _xform_network_availability_zone(az):
     result = []
     zone_info = {}
-    zone_info['zone_name'] = getattr(az, 'name', '')
-    zone_info['zone_status'] = getattr(az, 'state', '')
+    zone_info['zone_name'] = az.name
+    zone_info['zone_status'] = az.state
     if 'unavailable' == zone_info['zone_status']:
         zone_info['zone_status'] = 'not available'
-    zone_info['zone_resource'] = getattr(az, 'resource', '')
+    zone_info['zone_resource'] = az.resource
     result.append(zone_info)
     return result
 
 
 class ListAvailabilityZone(command.Lister):
-    """List availability zones and their status"""
+    _description = _("List availability zones and their status")
 
     def get_parser(self, prog_name):
-        parser = super(ListAvailabilityZone, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             '--compute',
             action='store_true',
             default=False,
-            help='List compute availability zones')
+            help=_('List compute availability zones'),
+        )
         parser.add_argument(
             '--network',
             action='store_true',
             default=False,
-            help='List network availability zones')
+            help=_('List network availability zones'),
+        )
         parser.add_argument(
             '--volume',
             action='store_true',
             default=False,
-            help='List volume availability zones')
+            help=_('List volume availability zones'),
+        )
         parser.add_argument(
             '--long',
             action='store_true',
@@ -112,32 +117,33 @@ class ListAvailabilityZone(command.Lister):
         return parser
 
     def _get_compute_availability_zones(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         try:
-            data = compute_client.availability_zones.list()
-        except nova_exceptions.Forbidden as e:  # policy doesn't allow
+            data = compute_client.availability_zones(details=True)
+        except nova_exceptions.Forbidden:  # policy doesn't allow
             try:
-                data = compute_client.availability_zones.list(detailed=False)
+                data = compute_client.availability_zones(details=False)
             except Exception:
-                raise e
+                raise
 
-        # Argh, the availability zones are not iterable...
         result = []
         for zone in data:
             result += _xform_compute_availability_zone(zone, parsed_args.long)
         return result
 
     def _get_volume_availability_zones(self, parsed_args):
-        volume_client = self.app.client_manager.volume
+        volume_client = self.app.client_manager.sdk_connection.volume
         data = []
         try:
-            data = volume_client.availability_zones.list()
+            data = volume_client.availability_zones()
         except Exception as e:
-            self.log.debug('Volume availability zone exception: ' + str(e))
+            LOG.debug('Volume availability zone exception: %s', e)
             if parsed_args.volume:
-                message = "Availability zones list not supported by " \
-                          "Block Storage API"
-                self.log.warning(message)
+                message = _(
+                    "Availability zones list not supported by "
+                    "Block Storage API"
+                )
+                LOG.warning(message)
 
         result = []
         for zone in data:
@@ -148,14 +154,16 @@ class ListAvailabilityZone(command.Lister):
         network_client = self.app.client_manager.network
         try:
             # Verify that the extension exists.
-            network_client.find_extension('Availability Zone',
-                                          ignore_missing=False)
+            network_client.find_extension(
+                'Availability Zone', ignore_missing=False
+            )
         except Exception as e:
-            self.log.debug('Network availability zone exception: ' + str(e))
+            LOG.debug('Network availability zone exception: ', e)
             if parsed_args.network:
-                message = "Availability zones list not supported by " \
-                          "Network API"
-                self.log.warning(message)
+                message = _(
+                    "Availability zones list not supported by Network API"
+                )
+                LOG.warning(message)
             return []
 
         result = []
@@ -164,17 +172,24 @@ class ListAvailabilityZone(command.Lister):
         return result
 
     def take_action(self, parsed_args):
-
         if parsed_args.long:
-            columns = ('Zone Name', 'Zone Status', 'Zone Resource',
-                       'Host Name', 'Service Name', 'Service Status')
+            columns = (
+                'Zone Name',
+                'Zone Status',
+                'Zone Resource',
+                'Host Name',
+                'Service Name',
+                'Service Status',
+            )
         else:
             columns = ('Zone Name', 'Zone Status')
 
         # Show everything by default.
-        show_all = (not parsed_args.compute and
-                    not parsed_args.volume and
-                    not parsed_args.network)
+        show_all = (
+            not parsed_args.compute
+            and not parsed_args.volume
+            and not parsed_args.network
+        )
 
         result = []
         if parsed_args.compute or show_all:
@@ -184,7 +199,7 @@ class ListAvailabilityZone(command.Lister):
         if parsed_args.network or show_all:
             result += self._get_network_availability_zones(parsed_args)
 
-        return (columns,
-                (utils.get_dict_properties(
-                    s, columns
-                ) for s in result))
+        return (
+            columns,
+            (utils.get_dict_properties(s, columns) for s in result),
+        )
