@@ -15,16 +15,66 @@
 
 """Usage action implementations"""
 
-import collections
 import datetime
+import functools
 
-from novaclient import api_versions
+from cliff import columns as cliff_columns
 from osc_lib.command import command
 from osc_lib import utils
 
 from openstackclient.i18n import _
 
 
+# TODO(stephenfin): This exists in a couple of places and should be moved to a
+# common module
+class ProjectColumn(cliff_columns.FormattableColumn):
+    """Formattable column for project column.
+
+    Unlike the parent FormattableColumn class, the initializer of the class
+    takes project_cache as the second argument.
+    ``osc_lib.utils.get_item_properties`` instantiates ``FormattableColumn``
+    objects with a single parameter, the column value, so you need to pass a
+    partially initialized class like ``functools.partial(ProjectColumn,
+    project_cache)`` to use this.
+    """
+
+    def __init__(self, value, project_cache=None):
+        super().__init__(value)
+        self.project_cache = project_cache or {}
+
+    def human_readable(self):
+        project = self._value
+        if not project:
+            return ''
+
+        if project in self.project_cache.keys():
+            return self.project_cache[project].name
+
+        return project
+
+
+class CountColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return len(self._value) if self._value is not None else None
+
+
+class FloatColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return float("%.2f" % self._value)
+
+
+def _formatters(project_cache):
+    return {
+        'project_id': functools.partial(
+            ProjectColumn, project_cache=project_cache
+        ),
+        'server_usages': CountColumn,
+        'total_memory_mb_usage': FloatColumn,
+        'total_vcpus_usage': FloatColumn,
+        'total_local_gb_usage': FloatColumn,
+    }
+
+
 def _get_usage_marker(usage):
     marker = None
     if hasattr(usage, 'server_usages') and usage.server_usages:
@@ -49,10 +99,10 @@ def _merge_usage(usage, next_usage):
 
 def _merge_usage_list(usages, next_usage_list):
     for next_usage in next_usage_list:
-        if next_usage.tenant_id in usages:
-            _merge_usage(usages[next_usage.tenant_id], next_usage)
+        if next_usage.project_id in usages:
+            _merge_usage(usages[next_usage.project_id], next_usage)
         else:
-            usages[next_usage.tenant_id] = next_usage
+            usages[next_usage.project_id] = next_usage
 
 
 class ListUsage(command.Lister):
@@ -64,19 +114,20 @@ class ListUsage(command.Lister):
             "--start",
             metavar="<start>",
             default=None,
-            help=_("Usage range start date, ex 2012-01-20"
-                   " (default: 4 weeks ago)")
+            help=_(
+                "Usage range start date, ex 2012-01-20"
+                " (default: 4 weeks ago)"
+            ),
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)"),
         )
         return parser
 
     def take_action(self, parsed_args):
-
         def _format_project(project):
             if not project:
                 return ""
@@ -85,52 +136,45 @@ class ListUsage(command.Lister):
             else:
                 return project
 
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         columns = (
-            "tenant_id",
+            "project_id",
             "server_usages",
             "total_memory_mb_usage",
             "total_vcpus_usage",
-            "total_local_gb_usage"
+            "total_local_gb_usage",
         )
         column_headers = (
             "Project",
             "Servers",
             "RAM MB-Hours",
             "CPU Hours",
-            "Disk GB-Hours"
+            "Disk GB-Hours",
         )
 
-        dateformat = "%Y-%m-%d"
+        date_cli_format = "%Y-%m-%d"
+        date_api_format = "%Y-%m-%dT%H:%M:%S"
         now = datetime.datetime.utcnow()
 
         if parsed_args.start:
-            start = datetime.datetime.strptime(parsed_args.start, dateformat)
+            start = datetime.datetime.strptime(
+                parsed_args.start, date_cli_format
+            )
         else:
             start = now - datetime.timedelta(weeks=4)
 
         if parsed_args.end:
-            end = datetime.datetime.strptime(parsed_args.end, dateformat)
+            end = datetime.datetime.strptime(parsed_args.end, date_cli_format)
         else:
             end = now + datetime.timedelta(days=1)
 
-        if compute_client.api_version < api_versions.APIVersion("2.40"):
-            usage_list = compute_client.usage.list(start, end, detailed=True)
-        else:
-            # If the number of instances used to calculate the usage is greater
-            # than CONF.api.max_limit, the usage will be split across multiple
-            # requests and the responses will need to be merged back together.
-            usages = collections.OrderedDict()
-            usage_list = compute_client.usage.list(start, end, detailed=True)
-            _merge_usage_list(usages, usage_list)
-            marker = _get_usage_list_marker(usage_list)
-            while marker:
-                next_usage_list = compute_client.usage.list(
-                    start, end, detailed=True, marker=marker)
-                marker = _get_usage_list_marker(next_usage_list)
-                if marker:
-                    _merge_usage_list(usages, next_usage_list)
-            usage_list = list(usages.values())
+        usage_list = list(
+            compute_client.usages(
+                start=start.strftime(date_api_format),
+                end=end.strftime(date_api_format),
+                detailed=True,
+            )
+        )
 
         # Cache the project list
         project_cache = {}
@@ -142,22 +186,25 @@ class ListUsage(command.Lister):
             pass
 
         if parsed_args.formatter == 'table' and len(usage_list) > 0:
-            self.app.stdout.write(_("Usage from %(start)s to %(end)s: \n") % {
-                "start": start.strftime(dateformat),
-                "end": end.strftime(dateformat),
-            })
+            self.app.stdout.write(
+                _("Usage from %(start)s to %(end)s: \n")
+                % {
+                    "start": start.strftime(date_cli_format),
+                    "end": end.strftime(date_cli_format),
+                }
+            )
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns,
-                    formatters={
-                        'tenant_id': _format_project,
-                        'server_usages': lambda x: len(x),
-                        'total_memory_mb_usage': lambda x: float("%.2f" % x),
-                        'total_vcpus_usage': lambda x: float("%.2f" % x),
-                        'total_local_gb_usage': lambda x: float("%.2f" % x),
-                    },
-                ) for s in usage_list))
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
+                    formatters=_formatters(project_cache),
+                )
+                for s in usage_list
+            ),
+        )
 
 
 class ShowUsage(command.ShowOne):
@@ -169,36 +216,41 @@ class ShowUsage(command.ShowOne):
             "--project",
             metavar="<project>",
             default=None,
-            help=_("Name or ID of project to show usage for")
+            help=_("Name or ID of project to show usage for"),
         )
         parser.add_argument(
             "--start",
             metavar="<start>",
             default=None,
-            help=_("Usage range start date, ex 2012-01-20"
-                   " (default: 4 weeks ago)")
+            help=_(
+                "Usage range start date, ex 2012-01-20"
+                " (default: 4 weeks ago)"
+            ),
         )
         parser.add_argument(
             "--end",
             metavar="<end>",
             default=None,
-            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)")
+            help=_("Usage range end date, ex 2012-01-20 (default: tomorrow)"),
         )
         return parser
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
-        compute_client = self.app.client_manager.compute
-        dateformat = "%Y-%m-%d"
+        compute_client = self.app.client_manager.sdk_connection.compute
+        date_cli_format = "%Y-%m-%d"
+        date_api_format = "%Y-%m-%dT%H:%M:%S"
         now = datetime.datetime.utcnow()
 
         if parsed_args.start:
-            start = datetime.datetime.strptime(parsed_args.start, dateformat)
+            start = datetime.datetime.strptime(
+                parsed_args.start, date_cli_format
+            )
         else:
             start = now - datetime.timedelta(weeks=4)
 
         if parsed_args.end:
-            end = datetime.datetime.strptime(parsed_args.end, dateformat)
+            end = datetime.datetime.strptime(parsed_args.end, date_cli_format)
         else:
             end = now + datetime.timedelta(days=1)
 
@@ -211,28 +263,38 @@ class ShowUsage(command.ShowOne):
             # Get the project from the current auth
             project = self.app.client_manager.auth_ref.project_id
 
-        usage = compute_client.usage.get(project, start, end)
+        usage = compute_client.get_usage(
+            project=project,
+            start=start.strftime(date_api_format),
+            end=end.strftime(date_api_format),
+        )
 
         if parsed_args.formatter == 'table':
-            self.app.stdout.write(_(
-                "Usage from %(start)s to %(end)s on project %(project)s: \n"
-            ) % {
-                "start": start.strftime(dateformat),
-                "end": end.strftime(dateformat),
-                "project": project,
-            })
+            self.app.stdout.write(
+                _("Usage from %(start)s to %(end)s on project %(project)s: \n")
+                % {
+                    "start": start.strftime(date_cli_format),
+                    "end": end.strftime(date_cli_format),
+                    "project": project,
+                }
+            )
 
-        info = {}
-        info['Servers'] = (
-            len(usage.server_usages)
-            if hasattr(usage, "server_usages") else None)
-        info['RAM MB-Hours'] = (
-            float("%.2f" % usage.total_memory_mb_usage)
-            if hasattr(usage, "total_memory_mb_usage") else None)
-        info['CPU Hours'] = (
-            float("%.2f" % usage.total_vcpus_usage)
-            if hasattr(usage, "total_vcpus_usage") else None)
-        info['Disk GB-Hours'] = (
-            float("%.2f" % usage.total_local_gb_usage)
-            if hasattr(usage, "total_local_gb_usage") else None)
-        return zip(*sorted(info.items()))
+        columns = (
+            "project_id",
+            "server_usages",
+            "total_memory_mb_usage",
+            "total_vcpus_usage",
+            "total_local_gb_usage",
+        )
+        column_headers = (
+            "Project",
+            "Servers",
+            "RAM MB-Hours",
+            "CPU Hours",
+            "Disk GB-Hours",
+        )
+
+        data = utils.get_item_properties(
+            usage, columns, formatters=_formatters(None)
+        )
+        return column_headers, data
