@@ -16,15 +16,20 @@
 
 """Identity v2 EC2 Credentials action implementations"""
 
-import six
+import logging
 
-from openstackclient.common import command
-from openstackclient.common import utils
-from openstackclient.i18n import _  # noqa
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
+
+from openstackclient.i18n import _
+
+
+LOG = logging.getLogger(__name__)
 
 
 class CreateEC2Creds(command.ShowOne):
-    """Create EC2 credentials"""
+    _description = _("Create EC2 credentials")
 
     def get_parser(self, prog_name):
         parser = super(CreateEC2Creds, self).get_parser(prog_name)
@@ -72,22 +77,21 @@ class CreateEC2Creds(command.ShowOne):
         info.update(creds._info)
 
         if 'tenant_id' in info:
-            info.update(
-                {'project_id': info.pop('tenant_id')}
-            )
+            info.update({'project_id': info.pop('tenant_id')})
 
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
 
 
 class DeleteEC2Creds(command.Command):
-    """Delete EC2 credentials"""
+    _description = _("Delete EC2 credentials")
 
     def get_parser(self, prog_name):
         parser = super(DeleteEC2Creds, self).get_parser(prog_name)
         parser.add_argument(
-            'access_key',
+            'access_keys',
             metavar='<access-key>',
-            help=_('Credentials access key'),
+            nargs='+',
+            help=_('Credentials access key(s)'),
         )
         parser.add_argument(
             '--user',
@@ -108,11 +112,30 @@ class DeleteEC2Creds(command.Command):
             # Get the user from the current auth
             user = self.app.client_manager.auth_ref.user_id
 
-        identity_client.ec2.delete(user, parsed_args.access_key)
+        result = 0
+        for access_key in parsed_args.access_keys:
+            try:
+                identity_client.ec2.delete(user, access_key)
+            except Exception as e:
+                result += 1
+                LOG.error(
+                    _(
+                        "Failed to delete EC2 credentials with "
+                        "access key '%(access_key)s': %(e)s"
+                    ),
+                    {'access_key': access_key, 'e': e},
+                )
+
+        if result > 0:
+            total = len(parsed_args.access_keys)
+            msg = _(
+                "%(result)s of %(total)s EC2 keys failed " "to delete."
+            ) % {'result': result, 'total': total}
+            raise exceptions.CommandError(msg)
 
 
 class ListEC2Creds(command.Lister):
-    """List EC2 credentials"""
+    _description = _("List EC2 credentials")
 
     def get_parser(self, prog_name):
         parser = super(ListEC2Creds, self).get_parser(prog_name)
@@ -139,15 +162,21 @@ class ListEC2Creds(command.Lister):
         column_headers = ('Access', 'Secret', 'Project ID', 'User ID')
         data = identity_client.ec2.list(user)
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns,
+        return (
+            column_headers,
+            (
+                utils.get_item_properties(
+                    s,
+                    columns,
                     formatters={},
-                ) for s in data))
+                )
+                for s in data
+            ),
+        )
 
 
 class ShowEC2Creds(command.ShowOne):
-    """Display EC2 credentials details"""
+    _description = _("Display EC2 credentials details")
 
     def get_parser(self, prog_name):
         parser = super(ShowEC2Creds, self).get_parser(prog_name)
@@ -181,8 +210,6 @@ class ShowEC2Creds(command.ShowOne):
         info.update(creds._info)
 
         if 'tenant_id' in info:
-            info.update(
-                {'project_id': info.pop('tenant_id')}
-            )
+            info.update({'project_id': info.pop('tenant_id')})
 
-        return zip(*sorted(six.iteritems(info)))
+        return zip(*sorted(info.items()))
