@@ -20,7 +20,6 @@ import logging
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common
@@ -77,7 +76,7 @@ class CreateService(command.ShowOne):
         )
 
         service._info.pop('links')
-        return zip(*sorted(six.iteritems(service._info)))
+        return zip(*sorted(service._info.items()))
 
 
 class DeleteService(command.Command):
@@ -102,14 +101,19 @@ class DeleteService(command.Command):
                 identity_client.services.delete(service.id)
             except Exception as e:
                 result += 1
-                LOG.error(_("Failed to delete consumer with type, "
-                          "name or ID '%(service)s': %(e)s")
-                          % {'service': i, 'e': e})
+                LOG.error(
+                    _(
+                        "Failed to delete consumer with type, "
+                        "name or ID '%(service)s': %(e)s"
+                    ),
+                    {'service': i, 'e': e},
+                )
 
         if result > 0:
             total = len(parsed_args.service)
-            msg = (_("%(result)s of %(total)s services failed "
-                   "to delete.") % {'result': result, 'total': total})
+            msg = _(
+                "%(result)s of %(total)s services failed " "to delete."
+            ) % {'result': result, 'total': total}
             raise exceptions.CommandError(msg)
 
 
@@ -127,7 +131,6 @@ class ListService(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-
         if parsed_args.long:
             columns = ('ID', 'Name', 'Type', 'Description', 'Enabled')
         else:
@@ -180,8 +183,7 @@ class SetService(command.Command):
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.identity
 
-        service = common.find_service(identity_client,
-                                      parsed_args.service)
+        service = common.find_service(identity_client, parsed_args.service)
         kwargs = {}
         if parsed_args.type:
             kwargs['type'] = parsed_args.type
@@ -194,10 +196,7 @@ class SetService(command.Command):
         if parsed_args.disable:
             kwargs['enabled'] = False
 
-        identity_client.services.update(
-            service.id,
-            **kwargs
-        )
+        identity_client.services.update(service.id, **kwargs)
 
 
 class ShowService(command.ShowOne):
@@ -218,4 +217,4 @@ class ShowService(command.ShowOne):
         service = common.find_service(identity_client, parsed_args.service)
 
         service._info.pop('links')
-        return zip(*sorted(six.iteritems(service._info)))
+        return zip(*sorted(service._info.items()))
