@@ -506,8 +506,8 @@ class CreateImage(command.ShowOne):
                 raise exceptions.CommandError(msg)
 
             if (
-                len(parsed_args.sign_key_path) < 1 or
-                len(parsed_args.sign_cert_id) < 1
+                len(parsed_args.sign_key_path) < 1
+                or len(parsed_args.sign_cert_id) < 1
             ):
                 msg = _(
                     "'sign-key-path' and 'sign-cert-id' must both be "
@@ -596,10 +596,7 @@ class CreateImage(command.ShowOne):
         )
         kwargs = {}
         if volume_client.api_version < api_versions.APIVersion('3.1'):
-            if (
-                parsed_args.visibility or
-                parsed_args.is_protected is not None
-            ):
+            if parsed_args.visibility or parsed_args.is_protected is not None:
                 msg = _(
                     '--os-volume-api-version 3.1 or greater is required '
                     'to support the --public, --private, --community, '
@@ -618,7 +615,7 @@ class CreateImage(command.ShowOne):
             parsed_args.name,
             parsed_args.container_format,
             parsed_args.disk_format,
-            **kwargs
+            **kwargs,
         )
         info = body['os-volume_upload_image']
         try:
@@ -656,10 +653,16 @@ class DeleteImage(command.Command):
             nargs="+",
             help=_("Image(s) to delete (name or ID)"),
         )
+        parser.add_argument(
+            '--store',
+            metavar='<STORE>',
+            # default=None,
+            dest='store',
+            help=_('Store to delete image(s) from.'),
+        )
         return parser
 
     def take_action(self, parsed_args):
-
         del_result = 0
         image_client = self.app.client_manager.image
         for image in parsed_args.images:
@@ -668,7 +671,18 @@ class DeleteImage(command.Command):
                     image,
                     ignore_missing=False,
                 )
-                image_client.delete_image(image_obj.id)
+            except sdk_exceptions.ResourceNotFound as e:
+                msg = _("Unable to process request: %(e)s") % {'e': e}
+                raise exceptions.CommandError(msg)
+            try:
+                image_client.delete_image(
+                    image_obj.id,
+                    store=parsed_args.store,
+                    ignore_missing=False,
+                )
+            except sdk_exceptions.ResourceNotFound:
+                msg = _("Multi Backend support not enabled.")
+                raise exceptions.CommandError(msg)
             except Exception as e:
                 del_result += 1
                 msg = _(
@@ -1206,7 +1220,10 @@ class SetImage(command.Command):
             const="accepted",
             dest="membership",
             default=None,
-            help=_("Accept the image membership"),
+            help=_(
+                "Accept the image membership for either the project indicated "
+                "by '--project', if provided, or the current user's project"
+            ),
         )
         membership_group.add_argument(
             "--reject",
@@ -1214,7 +1231,10 @@ class SetImage(command.Command):
             const="rejected",
             dest="membership",
             default=None,
-            help=_("Reject the image membership"),
+            help=_(
+                "Reject the image membership for either the project indicated "
+                "by '--project', if provided, or the current user's project"
+            ),
         )
         membership_group.add_argument(
             "--pending",
@@ -1807,7 +1827,7 @@ class ImportImage(command.ShowOne):
             method=parsed_args.import_method,
             uri=parsed_args.uri,
             remote_region=parsed_args.remote_region,
-            remote_image=parsed_args.remote_image,
+            remote_image_id=parsed_args.remote_image,
             remote_service_interface=parsed_args.remote_service_interface,
             stores=parsed_args.stores,
             all_stores=parsed_args.all_stores,
@@ -1816,3 +1836,48 @@ class ImportImage(command.ShowOne):
 
         info = _format_image(image)
         return zip(*sorted(info.items()))
+
+
+class StoresInfo(command.Lister):
+    _description = _(
+        "Get available backends (only valid with Multi-Backend support)"
+    )
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            "--detail",
+            action='store_true',
+            default=None,
+            help=_(
+                'Shows details of stores (admin only) '
+                '(requires --os-image-api-version 2.15 or later)'
+            ),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        image_client = self.app.client_manager.image
+        try:
+            columns = ("id", "description", "is_default")
+            column_headers = ("ID", "Description", "Default")
+            if parsed_args.detail:
+                columns += ("properties",)
+                column_headers += ("Properties",)
+
+            data = list(image_client.stores(details=parsed_args.detail))
+        except sdk_exceptions.ResourceNotFound:
+            msg = _('Multi Backend support not enabled')
+            raise exceptions.CommandError(msg)
+        else:
+            return (
+                column_headers,
+                (
+                    utils.get_item_properties(
+                        store,
+                        columns,
+                        formatters=_formatters,
+                    )
+                    for store in data
+                ),
+            )
