@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import random
 import uuid
 
@@ -29,18 +28,17 @@ class FloatingIpTests(common.NetworkTests):
             cls.PRIVATE_NETWORK_NAME = uuid.uuid4().hex
 
             # Create a network for the floating ip
-            json_output = json.loads(cls.openstack(
-                'network create -f json ' +
-                '--external ' +
-                cls.EXTERNAL_NETWORK_NAME
-            ))
+            json_output = cls.openstack(
+                'network create ' + '--external ' + cls.EXTERNAL_NETWORK_NAME,
+                parse_output=True,
+            )
             cls.external_network_id = json_output["id"]
 
             # Create a private network for the port
-            json_output = json.loads(cls.openstack(
-                'network create -f json ' +
-                cls.PRIVATE_NETWORK_NAME
-            ))
+            json_output = cls.openstack(
+                'network create ' + cls.PRIVATE_NETWORK_NAME,
+                parse_output=True,
+            )
             cls.private_network_id = json_output["id"]
 
     @classmethod
@@ -48,9 +46,10 @@ class FloatingIpTests(common.NetworkTests):
         try:
             if cls.haz_network:
                 del_output = cls.openstack(
-                    'network delete ' +
-                    cls.EXTERNAL_NETWORK_NAME + ' ' +
-                    cls.PRIVATE_NETWORK_NAME
+                    'network delete '
+                    + cls.EXTERNAL_NETWORK_NAME
+                    + ' '
+                    + cls.PRIVATE_NETWORK_NAME
                 )
                 cls.assertOutput('', del_output)
         finally:
@@ -75,22 +74,27 @@ class FloatingIpTests(common.NetworkTests):
         # try 4 times
         for i in range(4):
             # Make a random subnet
-            subnet = ".".join(map(
-                str,
-                (random.randint(0, 223) for _ in range(3))
-            )) + ".0/26"
+            subnet = (
+                ".".join(map(str, (random.randint(0, 223) for _ in range(3))))
+                + ".0/26"
+            )
             try:
                 # Create a subnet for the network
-                json_output = json.loads(self.openstack(
-                    'subnet create -f json ' +
-                    '--network ' + network_name + ' ' +
-                    '--subnet-range ' + subnet + ' ' +
-                    subnet_name
-                ))
+                json_output = self.openstack(
+                    'subnet create '
+                    + '--network '
+                    + network_name
+                    + ' '
+                    + '--subnet-range '
+                    + subnet
+                    + ' '
+                    + subnet_name,
+                    parse_output=True,
+                )
                 self.assertIsNotNone(json_output["id"])
                 subnet_id = json_output["id"]
             except Exception:
-                if (i == 3):
+                if i == 3:
                     # raise the exception at the last time
                     raise
                 pass
@@ -104,16 +108,16 @@ class FloatingIpTests(common.NetworkTests):
 
         # Subnets must exist even if not directly referenced here
         ext_subnet_id = self._create_subnet(
-            self.EXTERNAL_NETWORK_NAME,
-            "ext-test-delete"
+            self.EXTERNAL_NETWORK_NAME, "ext-test-delete"
         )
         self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
-            '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+        json_output = self.openstack(
+            'floating ip create '
+            + '--description aaaa '
+            + self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.assertEqual(
@@ -121,11 +125,12 @@ class FloatingIpTests(common.NetworkTests):
             json_output["description"],
         )
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
-            '--description bbbb ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+        json_output = self.openstack(
+            'floating ip create '
+            + '--description bbbb '
+            + self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip2 = json_output["id"]
         self.assertEqual(
@@ -144,16 +149,16 @@ class FloatingIpTests(common.NetworkTests):
 
         # Subnets must exist even if not directly referenced here
         ext_subnet_id = self._create_subnet(
-            self.EXTERNAL_NETWORK_NAME,
-            "ext-test-delete"
+            self.EXTERNAL_NETWORK_NAME, "ext-test-delete"
         )
         self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
-            '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+        json_output = self.openstack(
+            'floating ip create '
+            + '--description aaaa '
+            + self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip1)
@@ -164,11 +169,12 @@ class FloatingIpTests(common.NetworkTests):
         self.assertIsNotNone(json_output["floating_network_id"])
         fip1 = json_output["floating_ip_address"]
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
-            '--description bbbb ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+        json_output = self.openstack(
+            'floating ip create '
+            + '--description bbbb '
+            + self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip2 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip2)
@@ -180,12 +186,13 @@ class FloatingIpTests(common.NetworkTests):
         fip2 = json_output["floating_ip_address"]
 
         # Test list
-        json_output = json.loads(self.openstack(
-            'floating ip list -f json'
-        ))
+        json_output = self.openstack(
+            'floating ip list',
+            parse_output=True,
+        )
         fip_map = {
-            item.get('ID'):
-                item.get('Floating IP Address') for item in json_output
+            item.get('ID'): item.get('Floating IP Address')
+            for item in json_output
         }
         # self.assertEqual(item_map, json_output)
         self.assertIn(ip1, fip_map.keys())
@@ -194,13 +201,13 @@ class FloatingIpTests(common.NetworkTests):
         self.assertIn(fip2, fip_map.values())
 
         # Test list --long
-        json_output = json.loads(self.openstack(
-            'floating ip list -f json ' +
-            '--long'
-        ))
+        json_output = self.openstack(
+            'floating ip list ' + '--long',
+            parse_output=True,
+        )
         fip_map = {
-            item.get('ID'):
-                item.get('Floating IP Address') for item in json_output
+            item.get('ID'): item.get('Floating IP Address')
+            for item in json_output
         }
         self.assertIn(ip1, fip_map.keys())
         self.assertIn(ip2, fip_map.keys())
@@ -214,10 +221,10 @@ class FloatingIpTests(common.NetworkTests):
 
         # TODO(dtroyer): add more filter tests
 
-        json_output = json.loads(self.openstack(
-            'floating ip show -f json ' +
-            ip1
-        ))
+        json_output = self.openstack(
+            'floating ip show ' + ip1,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         self.assertEqual(
             ip1,
@@ -238,24 +245,23 @@ class FloatingIpTests(common.NetworkTests):
 
         # Subnets must exist even if not directly referenced here
         ext_subnet_id = self._create_subnet(
-            self.EXTERNAL_NETWORK_NAME,
-            "ext-test-delete"
+            self.EXTERNAL_NETWORK_NAME, "ext-test-delete"
         )
         self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
         priv_subnet_id = self._create_subnet(
-            self.PRIVATE_NETWORK_NAME,
-            "priv-test-delete"
+            self.PRIVATE_NETWORK_NAME, "priv-test-delete"
         )
         self.addCleanup(self.openstack, 'subnet delete ' + priv_subnet_id)
 
         self.ROUTER = uuid.uuid4().hex
         self.PORT_NAME = uuid.uuid4().hex
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
-            '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+        json_output = self.openstack(
+            'floating ip create '
+            + '--description aaaa '
+            + self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip1)
@@ -264,32 +270,35 @@ class FloatingIpTests(common.NetworkTests):
             json_output["description"],
         )
 
-        json_output = json.loads(self.openstack(
-            'port create -f json ' +
-            '--network ' + self.PRIVATE_NETWORK_NAME + ' ' +
-            '--fixed-ip subnet=' + priv_subnet_id + ' ' +
-            self.PORT_NAME
-        ))
+        json_output = self.openstack(
+            'port create '
+            + '--network '
+            + self.PRIVATE_NETWORK_NAME
+            + ' '
+            + '--fixed-ip subnet='
+            + priv_subnet_id
+            + ' '
+            + self.PORT_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         port_id = json_output["id"]
 
-        json_output = json.loads(self.openstack(
-            'router create -f json ' +
-            self.ROUTER
-        ))
+        json_output = self.openstack(
+            'router create ' + self.ROUTER,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         self.addCleanup(self.openstack, 'router delete ' + self.ROUTER)
 
-        self.openstack(
-            'router add port ' +
-            self.ROUTER + ' ' +
-            port_id
-        )
+        self.openstack('router add port ' + self.ROUTER + ' ' + port_id)
 
         self.openstack(
-            'router set ' +
-            '--external-gateway ' + self.EXTERNAL_NETWORK_NAME + ' ' +
-            self.ROUTER
+            'router set '
+            + '--external-gateway '
+            + self.EXTERNAL_NETWORK_NAME
+            + ' '
+            + self.ROUTER
         )
         self.addCleanup(
             self.openstack,
@@ -300,20 +309,16 @@ class FloatingIpTests(common.NetworkTests):
             'router remove port ' + self.ROUTER + ' ' + port_id,
         )
 
-        self.openstack(
-            'floating ip set ' +
-            '--port ' + port_id + ' ' +
-            ip1
-        )
+        self.openstack('floating ip set ' + '--port ' + port_id + ' ' + ip1)
         self.addCleanup(
             self.openstack,
             'floating ip unset --port ' + ip1,
         )
 
-        json_output = json.loads(self.openstack(
-            'floating ip show -f json ' +
-            ip1
-        ))
+        json_output = self.openstack(
+            'floating ip show ' + ip1,
+            parse_output=True,
+        )
 
         self.assertEqual(
             port_id,
