@@ -26,15 +26,14 @@ class IPAvailabilityTests(common.NetworkTests):
             cls.NETWORK_NAME = uuid.uuid4().hex
 
             # Create a network for the subnet
-            cls.openstack(
-                'network create ' +
-                cls.NETWORK_NAME
-            )
+            cls.openstack('network create ' + cls.NETWORK_NAME)
             cmd_output = cls.openstack(
-                'subnet create ' +
-                '--network ' + cls.NETWORK_NAME + ' ' +
-                '--subnet-range 10.10.10.0/24 ' +
-                cls.NAME,
+                'subnet create '
+                + '--network '
+                + cls.NETWORK_NAME
+                + ' '
+                + '--subnet-range 10.10.10.0/24 '
+                + cls.NAME,
                 parse_output=True,
             )
             cls.assertOutput(cls.NAME, cmd_output['name'])
@@ -43,13 +42,9 @@ class IPAvailabilityTests(common.NetworkTests):
     def tearDownClass(cls):
         try:
             if cls.haz_network:
-                raw_subnet = cls.openstack(
-                    'subnet delete ' +
-                    cls.NAME
-                )
+                raw_subnet = cls.openstack('subnet delete ' + cls.NAME)
                 raw_network = cls.openstack(
-                    'network delete ' +
-                    cls.NETWORK_NAME
+                    'network delete ' + cls.NETWORK_NAME
                 )
                 cls.assertOutput('', raw_subnet)
                 cls.assertOutput('', raw_network)
@@ -66,7 +61,8 @@ class IPAvailabilityTests(common.NetworkTests):
         """Test ip availability list"""
         cmd_output = self.openstack(
             'ip availability list',
-            parse_output=True,)
+            parse_output=True,
+        )
         names = [x['Network Name'] for x in cmd_output]
         self.assertIn(self.NETWORK_NAME, names)
 
@@ -74,7 +70,8 @@ class IPAvailabilityTests(common.NetworkTests):
         """Test ip availability show"""
         cmd_output = self.openstack(
             'ip availability show ' + self.NETWORK_NAME,
-            parse_output=True,)
+            parse_output=True,
+        )
         self.assertEqual(
             self.NETWORK_NAME,
             cmd_output['network_name'],
