@@ -24,7 +24,6 @@ from openstackclient.tests.unit import utils
 
 
 class TestKeyValueAction(utils.TestCase):
-
     def setUp(self):
         super(TestKeyValueAction, self).setUp()
 
@@ -37,15 +36,20 @@ class TestKeyValueAction(utils.TestCase):
             action=parseractions.KeyValueAction,
             default={'green': '20%', 'format': '#rgb'},
             help='Property to store for this volume '
-                 '(repeat option to set multiple properties)',
+            '(repeat option to set multiple properties)',
         )
 
     def test_good_values(self):
-        results = self.parser.parse_args([
-            '--property', 'red=',
-            '--property', 'green=100%',
-            '--property', 'blue=50%',
-        ])
+        results = self.parser.parse_args(
+            [
+                '--property',
+                'red=',
+                '--property',
+                'green=100%',
+                '--property',
+                'blue=50%',
+            ]
+        )
 
         actual = getattr(results, 'property', {})
         # All should pass through unmolested
@@ -57,13 +61,13 @@ class TestKeyValueAction(utils.TestCase):
             argparse.ArgumentTypeError,
             self.parser.parse_args,
             [
-                '--property', 'red',
-            ]
+                '--property',
+                'red',
+            ],
         )
 
 
 class TestMultiKeyValueAction(utils.TestCase):
-
     def setUp(self):
         super(TestMultiKeyValueAction, self).setUp()
 
@@ -78,14 +82,18 @@ class TestMultiKeyValueAction(utils.TestCase):
             default=None,
             required_keys=['req1', 'req2'],
             optional_keys=['opt1', 'opt2'],
-            help='Test'
+            help='Test',
         )
 
     def test_good_values(self):
-        results = self.parser.parse_args([
-            '--test', 'req1=aaa,req2=bbb',
-            '--test', 'req1=,req2=',
-        ])
+        results = self.parser.parse_args(
+            [
+                '--test',
+                'req1=aaa,req2=bbb',
+                '--test',
+                'req1=,req2=',
+            ]
+        )
 
         actual = getattr(results, 'test', [])
         expect = [
@@ -103,13 +111,17 @@ class TestMultiKeyValueAction(utils.TestCase):
             default=None,
             required_keys=[],
             optional_keys=[],
-            help='Test'
+            help='Test',
         )
 
-        results = self.parser.parse_args([
-            '--test-empty', 'req1=aaa,req2=bbb',
-            '--test-empty', 'req1=,req2=',
-        ])
+        results = self.parser.parse_args(
+            [
+                '--test-empty',
+                'req1=aaa,req2=bbb',
+                '--test-empty',
+                'req1=,req2=',
+            ]
+        )
 
         actual = getattr(results, 'test_empty', [])
         expect = [
@@ -123,8 +135,9 @@ class TestMultiKeyValueAction(utils.TestCase):
             argparse.ArgumentTypeError,
             self.parser.parse_args,
             [
-                '--test', 'mmm,nnn=zzz',
-            ]
+                '--test',
+                'mmm,nnn=zzz',
+            ],
         )
 
     def test_error_values_without_comma(self):
@@ -132,8 +145,9 @@ class TestMultiKeyValueAction(utils.TestCase):
             argparse.ArgumentTypeError,
             self.parser.parse_args,
             [
-                '--test', 'mmmnnn',
-            ]
+                '--test',
+                'mmmnnn',
+            ],
         )
 
     def test_missing_key(self):
@@ -141,8 +155,9 @@ class TestMultiKeyValueAction(utils.TestCase):
             argparse.ArgumentTypeError,
             self.parser.parse_args,
             [
-                '--test', 'req2=ddd',
-            ]
+                '--test',
+                'req2=ddd',
+            ],
         )
 
     def test_invalid_key(self):
@@ -150,8 +165,9 @@ class TestMultiKeyValueAction(utils.TestCase):
             argparse.ArgumentTypeError,
             self.parser.parse_args,
             [
-                '--test', 'req1=aaa,req2=bbb,aaa=req1',
-            ]
+                '--test',
+                'req1=aaa,req2=bbb,aaa=req1',
+            ],
         )
 
     def test_required_keys_not_list(self):
@@ -165,7 +181,7 @@ class TestMultiKeyValueAction(utils.TestCase):
             default=None,
             required_keys={'aaa': 'bbb'},
             optional_keys=['opt1', 'opt2'],
-            help='Test'
+            help='Test',
         )
 
     def test_optional_keys_not_list(self):
@@ -179,12 +195,11 @@ class TestMultiKeyValueAction(utils.TestCase):
             default=None,
             required_keys=['req1', 'req2'],
             optional_keys={'aaa': 'bbb'},
-            help='Test'
+            help='Test',
         )
 
 
 class TestNonNegativeAction(utils.TestCase):
-
     def setUp(self):
         super(TestNonNegativeAction, self).setUp()
 
@@ -202,21 +217,17 @@ class TestNonNegativeAction(utils.TestCase):
         self.assertRaises(
             argparse.ArgumentTypeError,
             self.parser.parse_args,
-            "--foo -1".split()
+            "--foo -1".split(),
         )
 
     def test_zero_values(self):
-        results = self.parser.parse_args(
-            '--foo 0'.split()
-        )
+        results = self.parser.parse_args('--foo 0'.split())
 
         actual = getattr(results, 'foo', None)
         self.assertEqual(actual, 0)
 
     def test_positive_values(self):
-        results = self.parser.parse_args(
-            '--foo 1'.split()
-        )
+        results = self.parser.parse_args('--foo 1'.split())
 
         actual = getattr(results, 'foo', None)
         self.assertEqual(actual, 1)
