@@ -21,7 +21,6 @@ from openstackclient.tests.unit import utils
 
 
 class TestConsole(compute_fakes.TestComputev2):
-
     def setUp(self):
         super(TestConsole, self).setUp()
 
@@ -34,7 +33,7 @@ class TestConsole(compute_fakes.TestComputev2):
 
 
 class TestConsoleLog(TestConsole):
-    _server = compute_fakes.FakeServer.create_one_server()
+    _server = compute_fakes.create_one_server()
 
     def setUp(self):
         super(TestConsoleLog, self).setUp()
@@ -44,76 +43,65 @@ class TestConsoleLog(TestConsole):
         self.cmd = console.ShowConsoleLog(self.app, None)
 
     def test_show_no_args(self):
-        arglist = [
-        ]
-        verifylist = [
-        ]
-        self.assertRaises(utils.ParserException,
-                          self.check_parser,
-                          self.cmd,
-                          arglist,
-                          verifylist)
+        arglist = []
+        verifylist = []
+        self.assertRaises(
+            utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_show(self):
-        arglist = [
-            'fake_server'
-        ]
-        verifylist = [
-            ('server', 'fake_server')
-        ]
+        arglist = ['fake_server']
+        verifylist = [('server', 'fake_server')]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        output = {
-            'output': '1st line\n2nd line\n'
-        }
+        output = {'output': '1st line\n2nd line\n'}
         self.sdk_client.get_server_console_output.return_value = output
         self.cmd.take_action(parsed_args)
 
         self.sdk_client.find_server.assert_called_with(
-            name_or_id='fake_server', ignore_missing=False)
+            name_or_id='fake_server', ignore_missing=False
+        )
         self.sdk_client.get_server_console_output.assert_called_with(
-            self._server.id,
-            length=None
+            self._server.id, length=None
         )
         stdout = self.app.stdout.content
         self.assertEqual(stdout[0], output['output'])
 
     def test_show_lines(self):
-        arglist = [
-            'fake_server',
-            '--lines', '15'
-        ]
-        verifylist = [
-            ('server', 'fake_server'),
-            ('lines', 15)
-        ]
+        arglist = ['fake_server', '--lines', '15']
+        verifylist = [('server', 'fake_server'), ('lines', 15)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        output = {
-            'output': '1st line\n2nd line'
-        }
+        output = {'output': '1st line\n2nd line'}
         self.sdk_client.get_server_console_output.return_value = output
         self.cmd.take_action(parsed_args)
 
         self.sdk_client.find_server.assert_called_with(
-            name_or_id='fake_server', ignore_missing=False)
+            name_or_id='fake_server', ignore_missing=False
+        )
         self.sdk_client.get_server_console_output.assert_called_with(
-            self._server.id,
-            length=15
+            self._server.id, length=15
         )
 
 
 class TestConsoleUrlShow(TestConsole):
-    _server = compute_fakes.FakeServer.create_one_server()
+    _server = compute_fakes.create_one_server()
 
     def setUp(self):
         super(TestConsoleUrlShow, self).setUp()
         self.sdk_client.find_server.return_value = self._server
-        fake_console_data = {'url': 'http://localhost',
-                             'protocol': 'fake_protocol',
-                             'type': 'fake_type'}
+        fake_console_data = {
+            'url': 'http://localhost',
+            'protocol': 'fake_protocol',
+            'type': 'fake_type',
+        }
         self.sdk_client.create_console = mock.Mock(
-            return_value=fake_console_data)
+            return_value=fake_console_data
+        )
 
         self.columns = (
             'protocol',
@@ -123,7 +111,7 @@ class TestConsoleUrlShow(TestConsole):
         self.data = (
             fake_console_data['protocol'],
             fake_console_data['type'],
-            fake_console_data['url']
+            fake_console_data['url'],
         )
 
         self.cmd = console.ShowConsoleURL(self.app, None)
@@ -139,8 +127,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='novnc')
+            self._server.id, console_type='novnc'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -156,8 +144,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='novnc')
+            self._server.id, console_type='novnc'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -173,8 +161,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='xvpvnc')
+            self._server.id, console_type='xvpvnc'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -190,8 +178,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='spice-html5')
+            self._server.id, console_type='spice-html5'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -207,8 +195,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='rdp-html5')
+            self._server.id, console_type='rdp-html5'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -224,8 +212,8 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='serial')
+            self._server.id, console_type='serial'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
@@ -241,7 +229,7 @@ class TestConsoleUrlShow(TestConsole):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_console.assert_called_once_with(
-            self._server.id,
-            console_type='webmks')
+            self._server.id, console_type='webmks'
+        )
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
