@@ -27,7 +27,6 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestFlavor(compute_fakes.TestComputev2):
-
     def setUp(self):
         super(TestFlavor, self).setUp()
 
@@ -50,9 +49,7 @@ class TestFlavor(compute_fakes.TestComputev2):
 
 
 class TestFlavorCreate(TestFlavor):
-
-    flavor = compute_fakes.FakeFlavor.create_one_flavor(
-        attrs={'links': 'flavor-links'})
+    flavor = compute_fakes.create_one_flavor(attrs={'links': 'flavor-links'})
     project = identity_fakes.FakeProject.create_one_project()
 
     columns = (
@@ -67,7 +64,7 @@ class TestFlavorCreate(TestFlavor):
         'ram',
         'rxtx_factor',
         'swap',
-        'vcpus'
+        'vcpus',
     )
 
     data = (
@@ -108,10 +105,7 @@ class TestFlavorCreate(TestFlavor):
         self.cmd = flavor.CreateFlavor(self.app, None)
 
     def test_flavor_create_default_options(self):
-
-        arglist = [
-            self.flavor.name
-        ]
+        arglist = [self.flavor.name]
         verifylist = [
             ('name', self.flavor.name),
         ]
@@ -136,18 +130,26 @@ class TestFlavorCreate(TestFlavor):
         self.assertCountEqual(self.data, data)
 
     def test_flavor_create_all_options(self):
-
         arglist = [
-            '--id', self.flavor.id,
-            '--ram', str(self.flavor.ram),
-            '--disk', str(self.flavor.disk),
-            '--ephemeral', str(self.flavor.ephemeral),
-            '--swap', str(self.flavor.swap),
-            '--vcpus', str(self.flavor.vcpus),
-            '--rxtx-factor', str(self.flavor.rxtx_factor),
+            '--id',
+            self.flavor.id,
+            '--ram',
+            str(self.flavor.ram),
+            '--disk',
+            str(self.flavor.disk),
+            '--ephemeral',
+            str(self.flavor.ephemeral),
+            '--swap',
+            str(self.flavor.swap),
+            '--vcpus',
+            str(self.flavor.vcpus),
+            '--rxtx-factor',
+            str(self.flavor.rxtx_factor),
             '--public',
-            '--description', str(self.flavor.description),
-            '--property', 'property=value',
+            '--description',
+            str(self.flavor.description),
+            '--property',
+            'property=value',
             self.flavor.name,
         ]
         verifylist = [
@@ -175,7 +177,7 @@ class TestFlavorCreate(TestFlavor):
             'swap': self.flavor.swap,
             'rxtx_factor': self.flavor.rxtx_factor,
             'is_public': self.flavor.is_public,
-            'description': self.flavor.description
+            'description': self.flavor.description,
         }
 
         props = {'property': 'value'}
@@ -190,36 +192,49 @@ class TestFlavorCreate(TestFlavor):
         cmp_data = list(self.data)
         cmp_data[7] = format_columns.DictColumn(props)
         self.sdk_client.create_flavor.return_value = create_flavor
-        self.sdk_client.create_flavor_extra_specs.return_value = \
+        self.sdk_client.create_flavor_extra_specs.return_value = (
             expected_flavor
+        )
 
-        with mock.patch.object(sdk_utils, 'supports_microversion',
-                               return_value=True):
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        ):
             columns, data = self.cmd.take_action(parsed_args)
             self.sdk_client.create_flavor.assert_called_once_with(**args)
             self.sdk_client.create_flavor_extra_specs.assert_called_once_with(
-                create_flavor, props)
+                create_flavor, props
+            )
             self.sdk_client.get_flavor_access.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(tuple(cmp_data), data)
 
     def test_flavor_create_other_options(self):
-
         self.flavor.is_public = False
         arglist = [
-            '--id', 'auto',
-            '--ram', str(self.flavor.ram),
-            '--disk', str(self.flavor.disk),
-            '--ephemeral', str(self.flavor.ephemeral),
-            '--swap', str(self.flavor.swap),
-            '--vcpus', str(self.flavor.vcpus),
-            '--rxtx-factor', str(self.flavor.rxtx_factor),
+            '--id',
+            'auto',
+            '--ram',
+            str(self.flavor.ram),
+            '--disk',
+            str(self.flavor.disk),
+            '--ephemeral',
+            str(self.flavor.ephemeral),
+            '--swap',
+            str(self.flavor.swap),
+            '--vcpus',
+            str(self.flavor.vcpus),
+            '--rxtx-factor',
+            str(self.flavor.rxtx_factor),
             '--private',
-            '--description', str(self.flavor.description),
-            '--project', self.project.id,
-            '--property', 'key1=value1',
-            '--property', 'key2=value2',
+            '--description',
+            str(self.flavor.description),
+            '--project',
+            self.project.id,
+            '--property',
+            'key1=value1',
+            '--property',
+            'key2=value2',
             self.flavor.name,
         ]
         verifylist = [
@@ -247,7 +262,7 @@ class TestFlavorCreate(TestFlavor):
             'swap': self.flavor.swap,
             'rxtx_factor': self.flavor.rxtx_factor,
             'is_public': False,
-            'description': self.flavor.description
+            'description': self.flavor.description,
         }
 
         props = {'key1': 'value1', 'key2': 'value2'}
@@ -263,11 +278,13 @@ class TestFlavorCreate(TestFlavor):
         cmp_data = list(self.data_private)
         cmp_data[7] = format_columns.DictColumn(props)
         self.sdk_client.create_flavor.return_value = create_flavor
-        self.sdk_client.create_flavor_extra_specs.return_value = \
+        self.sdk_client.create_flavor_extra_specs.return_value = (
             expected_flavor
+        )
 
-        with mock.patch.object(sdk_utils, 'supports_microversion',
-                               return_value=True):
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        ):
             columns, data = self.cmd.take_action(parsed_args)
         self.sdk_client.create_flavor.assert_called_once_with(**args)
         self.sdk_client.flavor_add_tenant_access.assert_called_with(
@@ -275,13 +292,15 @@ class TestFlavorCreate(TestFlavor):
             self.project.id,
         )
         self.sdk_client.create_flavor_extra_specs.assert_called_with(
-            create_flavor, props)
+            create_flavor, props
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(cmp_data, data)
 
     def test_public_flavor_create_with_project(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
             self.flavor.name,
         ]
         verifylist = [
@@ -290,30 +309,40 @@ class TestFlavorCreate(TestFlavor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.assertRaises(exceptions.CommandError,
-                          self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
     def test_flavor_create_no_options(self):
         arglist = []
         verifylist = None
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser,
-                          self.cmd,
-                          arglist,
-                          verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_flavor_create_with_description_api_newer(self):
         arglist = [
-            '--id', self.flavor.id,
-            '--ram', str(self.flavor.ram),
-            '--disk', str(self.flavor.disk),
-            '--ephemeral', str(self.flavor.ephemeral),
-            '--swap', str(self.flavor.swap),
-            '--vcpus', str(self.flavor.vcpus),
-            '--rxtx-factor', str(self.flavor.rxtx_factor),
+            '--id',
+            self.flavor.id,
+            '--ram',
+            str(self.flavor.ram),
+            '--disk',
+            str(self.flavor.disk),
+            '--ephemeral',
+            str(self.flavor.ephemeral),
+            '--swap',
+            str(self.flavor.swap),
+            '--vcpus',
+            str(self.flavor.vcpus),
+            '--rxtx-factor',
+            str(self.flavor.rxtx_factor),
             '--private',
-            '--description', 'fake description',
+            '--description',
+            'fake description',
             self.flavor.name,
         ]
         verifylist = [
@@ -329,9 +358,9 @@ class TestFlavorCreate(TestFlavor):
             ('name', self.flavor.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        with mock.patch.object(sdk_utils, 'supports_microversion',
-                               return_value=True):
-
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        ):
             columns, data = self.cmd.take_action(parsed_args)
 
         args = {
@@ -344,7 +373,7 @@ class TestFlavorCreate(TestFlavor):
             'swap': self.flavor.swap,
             'rxtx_factor': self.flavor.rxtx_factor,
             'is_public': self.flavor.is_public,
-            'description': 'fake description'
+            'description': 'fake description',
         }
 
         self.sdk_client.create_flavor.assert_called_once_with(**args)
@@ -354,10 +383,14 @@ class TestFlavorCreate(TestFlavor):
 
     def test_flavor_create_with_description_api_older(self):
         arglist = [
-            '--id', self.flavor.id,
-            '--ram', str(self.flavor.ram),
-            '--vcpus', str(self.flavor.vcpus),
-            '--description', 'description',
+            '--id',
+            self.flavor.id,
+            '--ram',
+            str(self.flavor.ram),
+            '--vcpus',
+            str(self.flavor.vcpus),
+            '--description',
+            'description',
             self.flavor.name,
         ]
         verifylist = [
@@ -368,15 +401,16 @@ class TestFlavorCreate(TestFlavor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        with mock.patch.object(sdk_utils, 'supports_microversion',
-                               return_value=False):
-            self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                              parsed_args)
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=False
+        ):
+            self.assertRaises(
+                exceptions.CommandError, self.cmd.take_action, parsed_args
+            )
 
 
 class TestFlavorDelete(TestFlavor):
-
-    flavors = compute_fakes.FakeFlavor.create_flavors(count=2)
+    flavors = compute_fakes.create_flavors(count=2)
 
     def setUp(self):
         super(TestFlavorDelete, self).setUp()
@@ -386,9 +420,7 @@ class TestFlavorDelete(TestFlavor):
         self.cmd = flavor.DeleteFlavor(self.app, None)
 
     def test_flavor_delete(self):
-        arglist = [
-            self.flavors[0].id
-        ]
+        arglist = [self.flavors[0].id]
         verifylist = [
             ('flavor', [self.flavors[0].id]),
         ]
@@ -398,8 +430,9 @@ class TestFlavorDelete(TestFlavor):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.sdk_client.find_flavor.assert_called_with(self.flavors[0].id,
-                                                       ignore_missing=False)
+        self.sdk_client.find_flavor.assert_called_with(
+            self.flavors[0].id, ignore_missing=False
+        )
         self.sdk_client.delete_flavor.assert_called_with(self.flavors[0].id)
         self.assertIsNone(result)
 
@@ -430,14 +463,12 @@ class TestFlavorDelete(TestFlavor):
             self.flavors[0].id,
             'unexist_flavor',
         ]
-        verifylist = [
-            ('flavor', [self.flavors[0].id, 'unexist_flavor'])
-        ]
+        verifylist = [('flavor', [self.flavors[0].id, 'unexist_flavor'])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.sdk_client.find_flavor.side_effect = [
             self.flavors[0],
-            sdk_exceptions.ResourceNotFound
+            sdk_exceptions.ResourceNotFound,
         ]
 
         try:
@@ -456,8 +487,7 @@ class TestFlavorDelete(TestFlavor):
 
 
 class TestFlavorList(TestFlavor):
-
-    _flavor = compute_fakes.FakeFlavor.create_one_flavor()
+    _flavor = compute_fakes.create_one_flavor()
 
     columns = (
         'ID',
@@ -468,32 +498,36 @@ class TestFlavorList(TestFlavor):
         'VCPUs',
         'Is Public',
     )
-    columns_long = columns + (
-        'Swap',
-        'RXTX Factor',
-        'Properties'
-    )
+    columns_long = columns + ('Swap', 'RXTX Factor', 'Properties')
 
-    data = ((
-        _flavor.id,
-        _flavor.name,
-        _flavor.ram,
-        _flavor.disk,
-        _flavor.ephemeral,
-        _flavor.vcpus,
-        _flavor.is_public,
-    ),)
-    data_long = (data[0] + (
-        _flavor.swap,
-        _flavor.rxtx_factor,
-        format_columns.DictColumn(_flavor.extra_specs)
-    ), )
+    data = (
+        (
+            _flavor.id,
+            _flavor.name,
+            _flavor.ram,
+            _flavor.disk,
+            _flavor.ephemeral,
+            _flavor.vcpus,
+            _flavor.is_public,
+        ),
+    )
+    data_long = (
+        data[0]
+        + (
+            _flavor.swap,
+            _flavor.rxtx_factor,
+            format_columns.DictColumn(_flavor.extra_specs),
+        ),
+    )
 
     def setUp(self):
         super(TestFlavorList, self).setUp()
 
         self.api_mock = mock.Mock()
-        self.api_mock.side_effect = [[self._flavor], [], ]
+        self.api_mock.side_effect = [
+            [self._flavor],
+            [],
+        ]
 
         self.sdk_client.flavors = self.api_mock
 
@@ -520,9 +554,8 @@ class TestFlavorList(TestFlavor):
             'is_public': True,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
-        )
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -547,9 +580,8 @@ class TestFlavorList(TestFlavor):
             'is_public': None,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
-        )
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -574,9 +606,8 @@ class TestFlavorList(TestFlavor):
             'is_public': False,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
-        )
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -601,9 +632,8 @@ class TestFlavorList(TestFlavor):
             'is_public': True,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
-        )
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -628,8 +658,64 @@ class TestFlavorList(TestFlavor):
             'is_public': True,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
+
+        self.assertEqual(self.columns_long, columns)
+        self.assertCountEqual(self.data_long, tuple(data))
+
+    def test_flavor_list_long_no_extra_specs(self):
+        # use flavor with no extra specs for this test
+        flavor = compute_fakes.create_one_flavor(attrs={"extra_specs": {}})
+        self.data = (
+            (
+                flavor.id,
+                flavor.name,
+                flavor.ram,
+                flavor.disk,
+                flavor.ephemeral,
+                flavor.vcpus,
+                flavor.is_public,
+            ),
+        )
+        self.data_long = (
+            self.data[0]
+            + (
+                flavor.swap,
+                flavor.rxtx_factor,
+                format_columns.DictColumn(flavor.extra_specs),
+            ),
+        )
+        self.api_mock.side_effect = [
+            [flavor],
+            [],
+        ]
+
+        self.sdk_client.flavors = self.api_mock
+        self.sdk_client.fetch_flavor_extra_specs = mock.Mock(return_value=None)
+
+        arglist = [
+            '--long',
+        ]
+        verifylist = [
+            ('long', True),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'is_public': True,
+        }
+
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_called_once_with(
+            flavor
         )
 
         self.assertEqual(self.columns_long, columns)
@@ -637,8 +723,10 @@ class TestFlavorList(TestFlavor):
 
     def test_flavor_list_min_disk_min_ram(self):
         arglist = [
-            '--min-disk', '10',
-            '--min-ram', '2048',
+            '--min-disk',
+            '10',
+            '--min-ram',
+            '2048',
         ]
         verifylist = [
             ('min_disk', 10),
@@ -659,19 +747,18 @@ class TestFlavorList(TestFlavor):
             'min_ram': 2048,
         }
 
-        self.sdk_client.flavors.assert_called_with(
-            **kwargs
-        )
+        self.sdk_client.flavors.assert_called_with(**kwargs)
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(tuple(self.data), tuple(data))
 
 
 class TestFlavorSet(TestFlavor):
-
     # Return value of self.sdk_client.find_flavor().
-    flavor = compute_fakes.FakeFlavor.create_one_flavor(
-        attrs={'os-flavor-access:is_public': False})
+    flavor = compute_fakes.create_one_flavor(
+        attrs={'os-flavor-access:is_public': False}
+    )
     project = identity_fakes.FakeProject.create_one_project()
 
     def setUp(self):
@@ -683,51 +770,40 @@ class TestFlavorSet(TestFlavor):
         self.cmd = flavor.SetFlavor(self.app, None)
 
     def test_flavor_set_property(self):
-        arglist = [
-            '--property', 'FOO="B A R"',
-            'baremetal'
-        ]
+        arglist = ['--property', 'FOO="B A R"', 'baremetal']
         verifylist = [
             ('properties', {'FOO': '"B A R"'}),
-            ('flavor', 'baremetal')
+            ('flavor', 'baremetal'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
         )
         self.sdk_client.create_flavor_extra_specs.assert_called_with(
-            self.flavor.id,
-            {'FOO': '"B A R"'})
+            self.flavor.id, {'FOO': '"B A R"'}
+        )
         self.assertIsNone(result)
 
     def test_flavor_set_no_property(self):
-        arglist = [
-            '--no-property',
-            'baremetal'
-        ]
-        verifylist = [
-            ('no_property', True),
-            ('flavor', 'baremetal')
-        ]
+        arglist = ['--no-property', 'baremetal']
+        verifylist = [('no_property', True), ('flavor', 'baremetal')]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
         )
         self.sdk_client.delete_flavor_extra_specs_property.assert_called_with(
-            self.flavor.id, 'property')
+            self.flavor.id, 'property'
+        )
         self.assertIsNone(result)
 
     def test_flavor_set_project(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
             self.flavor.id,
         ]
         verifylist = [
@@ -739,9 +815,7 @@ class TestFlavorSet(TestFlavor):
         result = self.cmd.take_action(parsed_args)
 
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
         )
         self.sdk_client.flavor_add_tenant_access.assert_called_with(
             self.flavor.id,
@@ -759,18 +833,29 @@ class TestFlavorSet(TestFlavor):
             ('project', None),
             ('flavor', self.flavor.id),
         ]
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_flavor_set_no_flavor(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
         ]
         verifylist = [
             ('project', self.project.id),
         ]
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_flavor_set_with_unexist_flavor(self):
         self.sdk_client.find_flavor.side_effect = [
@@ -778,7 +863,8 @@ class TestFlavorSet(TestFlavor):
         ]
 
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
             'unexist_flavor',
         ]
         verifylist = [
@@ -787,9 +873,9 @@ class TestFlavorSet(TestFlavor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.assertRaises(exceptions.CommandError,
-                          self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
     def test_flavor_set_nothing(self):
         arglist = [
@@ -802,16 +888,15 @@ class TestFlavorSet(TestFlavor):
         result = self.cmd.take_action(parsed_args)
 
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
         )
         self.sdk_client.flavor_add_tenant_access.assert_not_called()
         self.assertIsNone(result)
 
     def test_flavor_set_description_api_newer(self):
         arglist = [
-            '--description', 'description',
+            '--description',
+            'description',
             self.flavor.id,
         ]
         verifylist = [
@@ -820,17 +905,19 @@ class TestFlavorSet(TestFlavor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.app.client_manager.compute.api_version = 2.55
-        with mock.patch.object(sdk_utils,
-                               'supports_microversion',
-                               return_value=True):
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        ):
             result = self.cmd.take_action(parsed_args)
             self.sdk_client.update_flavor.assert_called_with(
-                flavor=self.flavor.id, description='description')
+                flavor=self.flavor.id, description='description'
+            )
             self.assertIsNone(result)
 
     def test_flavor_set_description_api_older(self):
         arglist = [
-            '--description', 'description',
+            '--description',
+            'description',
             self.flavor.id,
         ]
         verifylist = [
@@ -839,15 +926,17 @@ class TestFlavorSet(TestFlavor):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.app.client_manager.compute.api_version = 2.54
-        with mock.patch.object(sdk_utils,
-                               'supports_microversion',
-                               return_value=False):
-            self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                              parsed_args)
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=False
+        ):
+            self.assertRaises(
+                exceptions.CommandError, self.cmd.take_action, parsed_args
+            )
 
     def test_flavor_set_description_using_name_api_newer(self):
         arglist = [
-            '--description', 'description',
+            '--description',
+            'description',
             self.flavor.name,
         ]
         verifylist = [
@@ -857,17 +946,19 @@ class TestFlavorSet(TestFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.app.client_manager.compute.api_version = 2.55
 
-        with mock.patch.object(sdk_utils,
-                               'supports_microversion',
-                               return_value=True):
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        ):
             result = self.cmd.take_action(parsed_args)
             self.sdk_client.update_flavor.assert_called_with(
-                flavor=self.flavor.id, description='description')
+                flavor=self.flavor.id, description='description'
+            )
             self.assertIsNone(result)
 
     def test_flavor_set_description_using_name_api_older(self):
         arglist = [
-            '--description', 'description',
+            '--description',
+            'description',
             self.flavor.name,
         ]
         verifylist = [
@@ -877,18 +968,18 @@ class TestFlavorSet(TestFlavor):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.app.client_manager.compute.api_version = 2.54
 
-        with mock.patch.object(sdk_utils,
-                               'supports_microversion',
-                               return_value=False):
-            self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                              parsed_args)
+        with mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=False
+        ):
+            self.assertRaises(
+                exceptions.CommandError, self.cmd.take_action, parsed_args
+            )
 
 
 class TestFlavorShow(TestFlavor):
-
     # Return value of self.sdk_client.find_flavor().
-    flavor_access = compute_fakes.FakeFlavorAccess.create_one_flavor_access()
-    flavor = compute_fakes.FakeFlavor.create_one_flavor()
+    flavor_access = compute_fakes.create_one_flavor_access()
+    flavor = compute_fakes.create_one_flavor()
 
     columns = (
         'OS-FLV-DISABLED:disabled',
@@ -903,7 +994,7 @@ class TestFlavorShow(TestFlavor):
         'ram',
         'rxtx_factor',
         'swap',
-        'vcpus'
+        'vcpus',
     )
 
     data = (
@@ -935,8 +1026,13 @@ class TestFlavorShow(TestFlavor):
         verifylist = []
 
         # Missing required args should boil here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_public_flavor_show(self):
         arglist = [
@@ -954,7 +1050,7 @@ class TestFlavorShow(TestFlavor):
         self.assertCountEqual(self.data, data)
 
     def test_private_flavor_show(self):
-        private_flavor = compute_fakes.FakeFlavor.create_one_flavor(
+        private_flavor = compute_fakes.create_one_flavor(
             attrs={
                 'os-flavor-access:is_public': False,
             }
@@ -989,16 +1085,17 @@ class TestFlavorShow(TestFlavor):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.sdk_client.get_flavor_access.assert_called_with(
-            flavor=private_flavor.id)
+            flavor=private_flavor.id
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(data_with_project, data)
 
 
 class TestFlavorUnset(TestFlavor):
-
     # Return value of self.sdk_client.find_flavor().
-    flavor = compute_fakes.FakeFlavor.create_one_flavor(
-        attrs={'os-flavor-access:is_public': False})
+    flavor = compute_fakes.create_one_flavor(
+        attrs={'os-flavor-access:is_public': False}
+    )
     project = identity_fakes.FakeProject.create_one_project()
 
     def setUp(self):
@@ -1012,10 +1109,7 @@ class TestFlavorUnset(TestFlavor):
         self.mock_shortcut = self.sdk_client.delete_flavor_extra_specs_property
 
     def test_flavor_unset_property(self):
-        arglist = [
-            '--property', 'property',
-            'baremetal'
-        ]
+        arglist = ['--property', 'property', 'baremetal']
         verifylist = [
             ('properties', ['property']),
             ('flavor', 'baremetal'),
@@ -1024,19 +1118,19 @@ class TestFlavorUnset(TestFlavor):
 
         result = self.cmd.take_action(parsed_args)
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False)
-        self.mock_shortcut.assert_called_with(
-            self.flavor.id, 'property')
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
+        )
+        self.mock_shortcut.assert_called_with(self.flavor.id, 'property')
         self.sdk_client.flavor_remove_tenant_access.assert_not_called()
         self.assertIsNone(result)
 
     def test_flavor_unset_properties(self):
         arglist = [
-            '--property', 'property1',
-            '--property', 'property2',
-            'baremetal'
+            '--property',
+            'property1',
+            '--property',
+            'property2',
+            'baremetal',
         ]
         verifylist = [
             ('properties', ['property1', 'property2']),
@@ -1046,29 +1140,26 @@ class TestFlavorUnset(TestFlavor):
 
         self.cmd.take_action(parsed_args)
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor,
-            get_extra_specs=True,
-            ignore_missing=False)
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
+        )
         calls = [
             mock.call(self.flavor.id, 'property1'),
-            mock.call(self.flavor.id, 'property2')
+            mock.call(self.flavor.id, 'property2'),
         ]
-        self.mock_shortcut.assert_has_calls(
-            calls)
+        self.mock_shortcut.assert_has_calls(calls)
 
         # A bit tricky way to ensure we do not unset other properties
         calls.append(mock.call(self.flavor.id, 'property'))
         self.assertRaises(
-            AssertionError,
-            self.mock_shortcut.assert_has_calls,
-            calls
+            AssertionError, self.mock_shortcut.assert_has_calls, calls
         )
 
         self.sdk_client.flavor_remove_tenant_access.assert_not_called()
 
     def test_flavor_unset_project(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
             self.flavor.id,
         ]
         verifylist = [
@@ -1081,8 +1172,8 @@ class TestFlavorUnset(TestFlavor):
         self.assertIsNone(result)
 
         self.sdk_client.find_flavor.assert_called_with(
-            parsed_args.flavor, get_extra_specs=True,
-            ignore_missing=False)
+            parsed_args.flavor, get_extra_specs=True, ignore_missing=False
+        )
         self.sdk_client.flavor_remove_tenant_access.assert_called_with(
             self.flavor.id,
             self.project.id,
@@ -1099,18 +1190,29 @@ class TestFlavorUnset(TestFlavor):
             ('project', None),
             ('flavor', self.flavor.id),
         ]
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_flavor_unset_no_flavor(self):
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
         ]
         verifylist = [
             ('project', self.project.id),
         ]
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_flavor_unset_with_unexist_flavor(self):
         self.sdk_client.find_flavor.side_effect = [
@@ -1118,7 +1220,8 @@ class TestFlavorUnset(TestFlavor):
         ]
 
         arglist = [
-            '--project', self.project.id,
+            '--project',
+            self.project.id,
             'unexist_flavor',
         ]
         verifylist = [
@@ -1126,8 +1229,9 @@ class TestFlavorUnset(TestFlavor):
             ('flavor', 'unexist_flavor'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                          parsed_args)
+        self.assertRaises(
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
     def test_flavor_unset_nothing(self):
         arglist = [
