@@ -30,7 +30,6 @@ from openstackclient.tests.unit import utils as tests_utils
 
 
 class TestKeypair(compute_fakes.TestComputev2):
-
     def setUp(self):
         super(TestKeypair, self).setUp()
 
@@ -53,23 +52,28 @@ class TestKeypair(compute_fakes.TestComputev2):
 
 
 class TestKeypairCreate(TestKeypair):
-
-    keypair = compute_fakes.FakeKeypair.create_one_keypair()
-
     def setUp(self):
-        super(TestKeypairCreate, self).setUp()
+        super().setUp()
+
+        self.keypair = compute_fakes.create_one_keypair()
 
         self.columns = (
+            'created_at',
             'fingerprint',
+            'id',
+            'is_deleted',
             'name',
             'type',
-            'user_id'
+            'user_id',
         )
         self.data = (
+            self.keypair.created_at,
             self.keypair.fingerprint,
+            self.keypair.id,
+            self.keypair.is_deleted,
             self.keypair.name,
             self.keypair.type,
-            self.keypair.user_id
+            self.keypair.user_id,
         )
 
         # Get the command object to test
@@ -77,8 +81,12 @@ class TestKeypairCreate(TestKeypair):
 
         self.sdk_client.create_keypair.return_value = self.keypair
 
-    def test_key_pair_create_no_options(self):
-
+    @mock.patch.object(
+        keypair,
+        '_generate_keypair',
+        return_value=keypair.Keypair('private', 'public'),
+    )
+    def test_keypair_create_no_options(self, mock_generate):
         arglist = [
             self.keypair.name,
         ]
@@ -90,27 +98,27 @@ class TestKeypairCreate(TestKeypair):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.sdk_client.create_keypair.assert_called_with(
-            name=self.keypair.name
+            name=self.keypair.name,
+            public_key=mock_generate.return_value.public_key,
         )
 
         self.assertEqual({}, columns)
         self.assertEqual({}, data)
 
     def test_keypair_create_public_key(self):
-        # overwrite the setup one because we want to omit private_key
-        self.keypair = compute_fakes.FakeKeypair.create_one_keypair(
-            no_pri=True)
-        self.sdk_client.create_keypair.return_value = self.keypair
-
         self.data = (
+            self.keypair.created_at,
             self.keypair.fingerprint,
+            self.keypair.id,
+            self.keypair.is_deleted,
             self.keypair.name,
             self.keypair.type,
-            self.keypair.user_id
+            self.keypair.user_id,
         )
 
         arglist = [
-            '--public-key', self.keypair.public_key,
+            '--public-key',
+            self.keypair.public_key,
             self.keypair.name,
         ]
         verifylist = [
@@ -135,10 +143,16 @@ class TestKeypairCreate(TestKeypair):
             self.assertEqual(self.columns, columns)
             self.assertEqual(self.data, data)
 
-    def test_keypair_create_private_key(self):
+    @mock.patch.object(
+        keypair,
+        '_generate_keypair',
+        return_value=keypair.Keypair('private', 'public'),
+    )
+    def test_keypair_create_private_key(self, mock_generate):
         tmp_pk_file = '/tmp/kp-file-' + uuid.uuid4().hex
         arglist = [
-            '--private-key', tmp_pk_file,
+            '--private-key',
+            tmp_pk_file,
             self.keypair.name,
         ]
         verifylist = [
@@ -156,10 +170,13 @@ class TestKeypairCreate(TestKeypair):
 
             self.sdk_client.create_keypair.assert_called_with(
                 name=self.keypair.name,
+                public_key=mock_generate.return_value.public_key,
             )
 
             mock_open.assert_called_once_with(tmp_pk_file, 'w+')
-            m_file.write.assert_called_once_with(self.keypair.private_key)
+            m_file.write.assert_called_once_with(
+                mock_generate.return_value.private_key,
+            )
 
             self.assertEqual(self.columns, columns)
             self.assertEqual(self.data, data)
@@ -167,20 +184,23 @@ class TestKeypairCreate(TestKeypair):
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_create_with_key_type(self, sm_mock):
         for key_type in ['x509', 'ssh']:
-            self.keypair = compute_fakes.FakeKeypair.create_one_keypair(
-                no_pri=True)
             self.sdk_client.create_keypair.return_value = self.keypair
 
             self.data = (
+                self.keypair.created_at,
                 self.keypair.fingerprint,
+                self.keypair.id,
+                self.keypair.is_deleted,
                 self.keypair.name,
                 self.keypair.type,
                 self.keypair.user_id,
             )
             arglist = [
-                '--public-key', self.keypair.public_key,
+                '--public-key',
+                self.keypair.public_key,
                 self.keypair.name,
-                '--type', key_type,
+                '--type',
+                key_type,
             ]
             verifylist = [
                 ('public_key', self.keypair.public_key),
@@ -208,9 +228,11 @@ class TestKeypairCreate(TestKeypair):
     def test_keypair_create_with_key_type_pre_v22(self, sm_mock):
         for key_type in ['x509', 'ssh']:
             arglist = [
-                '--public-key', self.keypair.public_key,
+                '--public-key',
+                self.keypair.public_key,
                 self.keypair.name,
-                '--type', 'ssh',
+                '--type',
+                'ssh',
             ]
             verifylist = [
                 ('public_key', self.keypair.public_key),
@@ -225,18 +247,23 @@ class TestKeypairCreate(TestKeypair):
                 m_file.read.return_value = 'dummy'
 
                 ex = self.assertRaises(
-                    exceptions.CommandError,
-                    self.cmd.take_action,
-                    parsed_args)
+                    exceptions.CommandError, self.cmd.take_action, parsed_args
+                )
 
             self.assertIn(
-                '--os-compute-api-version 2.2 or greater is required',
-                str(ex))
+                '--os-compute-api-version 2.2 or greater is required', str(ex)
+            )
 
+    @mock.patch.object(
+        keypair,
+        '_generate_keypair',
+        return_value=keypair.Keypair('private', 'public'),
+    )
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
-    def test_key_pair_create_with_user(self, sm_mock):
+    def test_key_pair_create_with_user(self, sm_mock, mock_generate):
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
             self.keypair.name,
         ]
         verifylist = [
@@ -250,6 +277,7 @@ class TestKeypairCreate(TestKeypair):
         self.sdk_client.create_keypair.assert_called_with(
             name=self.keypair.name,
             user_id=identity_fakes.user_id,
+            public_key=mock_generate.return_value.public_key,
         )
 
         self.assertEqual({}, columns)
@@ -258,7 +286,8 @@ class TestKeypairCreate(TestKeypair):
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_key_pair_create_with_user_pre_v210(self, sm_mock):
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
             self.keypair.name,
         ]
         verifylist = [
@@ -268,26 +297,23 @@ class TestKeypairCreate(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn(
-            '--os-compute-api-version 2.10 or greater is required', str(ex))
+            '--os-compute-api-version 2.10 or greater is required', str(ex)
+        )
 
 
 class TestKeypairDelete(TestKeypair):
-
-    keypairs = compute_fakes.FakeKeypair.create_keypairs(count=2)
+    keypairs = compute_fakes.create_keypairs(count=2)
 
     def setUp(self):
-        super(TestKeypairDelete, self).setUp()
+        super().setUp()
 
         self.cmd = keypair.DeleteKeypair(self.app, None)
 
     def test_keypair_delete(self):
-        arglist = [
-            self.keypairs[0].name
-        ]
+        arglist = [self.keypairs[0].name]
         verifylist = [
             ('name', [self.keypairs[0].name]),
         ]
@@ -298,7 +324,8 @@ class TestKeypairDelete(TestKeypair):
 
         self.assertIsNone(ret)
         self.sdk_client.delete_keypair.assert_called_with(
-            self.keypairs[0].name, ignore_missing=False)
+            self.keypairs[0].name, ignore_missing=False
+        )
 
     def test_delete_multiple_keypairs(self):
         arglist = []
@@ -329,7 +356,9 @@ class TestKeypairDelete(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.sdk_client.delete_keypair.side_effect = [
-            None, exceptions.CommandError]
+            None,
+            exceptions.CommandError,
+        ]
         try:
             self.cmd.take_action(parsed_args)
             self.fail('CommandError should be raised.')
@@ -343,10 +372,7 @@ class TestKeypairDelete(TestKeypair):
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_delete_with_user(self, sm_mock):
-        arglist = [
-            '--user', identity_fakes.user_name,
-            self.keypairs[0].name
-        ]
+        arglist = ['--user', identity_fakes.user_name, self.keypairs[0].name]
         verifylist = [
             ('user', identity_fakes.user_name),
             ('name', [self.keypairs[0].name]),
@@ -359,19 +385,16 @@ class TestKeypairDelete(TestKeypair):
         self.sdk_client.delete_keypair.assert_called_with(
             self.keypairs[0].name,
             user_id=identity_fakes.user_id,
-            ignore_missing=False
+            ignore_missing=False,
         )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_keypair_delete_with_user_pre_v210(self, sm_mock):
+        self.app.client_manager.compute.api_version = api_versions.APIVersion(
+            '2.9'
+        )
 
-        self.app.client_manager.compute.api_version = \
-            api_versions.APIVersion('2.9')
-
-        arglist = [
-            '--user', identity_fakes.user_name,
-            self.keypairs[0].name
-        ]
+        arglist = ['--user', identity_fakes.user_name, self.keypairs[0].name]
         verifylist = [
             ('user', identity_fakes.user_name),
             ('name', [self.keypairs[0].name]),
@@ -379,20 +402,19 @@ class TestKeypairDelete(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn(
-            '--os-compute-api-version 2.10 or greater is required', str(ex))
+            '--os-compute-api-version 2.10 or greater is required', str(ex)
+        )
 
 
 class TestKeypairList(TestKeypair):
-
     # Return value of self.sdk_client.keypairs().
-    keypairs = compute_fakes.FakeKeypair.create_keypairs(count=1)
+    keypairs = compute_fakes.create_keypairs(count=1)
 
     def setUp(self):
-        super(TestKeypairList, self).setUp()
+        super().setUp()
 
         self.sdk_client.keypairs.return_value = self.keypairs
 
@@ -417,8 +439,8 @@ class TestKeypairList(TestKeypair):
 
         self.assertEqual(('Name', 'Fingerprint'), columns)
         self.assertEqual(
-            ((self.keypairs[0].name, self.keypairs[0].fingerprint), ),
-            tuple(data)
+            ((self.keypairs[0].name, self.keypairs[0].fingerprint),),
+            tuple(data),
         )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
@@ -439,17 +461,18 @@ class TestKeypairList(TestKeypair):
 
         self.assertEqual(('Name', 'Fingerprint', 'Type'), columns)
         self.assertEqual(
-            ((
-                self.keypairs[0].name,
-                self.keypairs[0].fingerprint,
-                self.keypairs[0].type,
-            ), ),
-            tuple(data)
+            (
+                (
+                    self.keypairs[0].name,
+                    self.keypairs[0].fingerprint,
+                    self.keypairs[0].type,
+                ),
+            ),
+            tuple(data),
         )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_list_with_user(self, sm_mock):
-
         users_mock = self.app.client_manager.identity.users
         users_mock.reset_mock()
         users_mock.get.return_value = fakes.FakeResource(
@@ -459,7 +482,8 @@ class TestKeypairList(TestKeypair):
         )
 
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
         ]
         verifylist = [
             ('user', identity_fakes.user_name),
@@ -475,19 +499,21 @@ class TestKeypairList(TestKeypair):
 
         self.assertEqual(('Name', 'Fingerprint', 'Type'), columns)
         self.assertEqual(
-            ((
-                self.keypairs[0].name,
-                self.keypairs[0].fingerprint,
-                self.keypairs[0].type,
-            ), ),
-            tuple(data)
+            (
+                (
+                    self.keypairs[0].name,
+                    self.keypairs[0].fingerprint,
+                    self.keypairs[0].type,
+                ),
+            ),
+            tuple(data),
         )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_keypair_list_with_user_pre_v210(self, sm_mock):
-
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
         ]
         verifylist = [
             ('user', identity_fakes.user_name),
@@ -495,15 +521,14 @@ class TestKeypairList(TestKeypair):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn(
-            '--os-compute-api-version 2.10 or greater is required', str(ex))
+            '--os-compute-api-version 2.10 or greater is required', str(ex)
+        )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_list_with_project(self, sm_mock):
-
         projects_mock = self.app.client_manager.identity.tenants
         projects_mock.reset_mock()
         projects_mock.get.return_value = fakes.FakeResource(
@@ -536,44 +561,52 @@ class TestKeypairList(TestKeypair):
 
         self.assertEqual(('Name', 'Fingerprint', 'Type'), columns)
         self.assertEqual(
-            ((
-                self.keypairs[0].name,
-                self.keypairs[0].fingerprint,
-                self.keypairs[0].type,
-            ), ),
-            tuple(data)
+            (
+                (
+                    self.keypairs[0].name,
+                    self.keypairs[0].fingerprint,
+                    self.keypairs[0].type,
+                ),
+            ),
+            tuple(data),
         )
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_keypair_list_with_project_pre_v210(self, sm_mock):
-
         arglist = ['--project', identity_fakes.project_name]
         verifylist = [('project', identity_fakes.project_name)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn(
-            '--os-compute-api-version 2.10 or greater is required', str(ex))
+            '--os-compute-api-version 2.10 or greater is required', str(ex)
+        )
 
     def test_keypair_list_conflicting_user_options(self):
-
         arglist = [
-            '--user', identity_fakes.user_name,
-            '--project', identity_fakes.project_name,
+            '--user',
+            identity_fakes.user_name,
+            '--project',
+            identity_fakes.project_name,
         ]
 
         self.assertRaises(
             tests_utils.ParserException,
-            self.check_parser, self.cmd, arglist, None)
+            self.check_parser,
+            self.cmd,
+            arglist,
+            None,
+        )
 
     @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True))
+        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True)
+    )
     def test_keypair_list_with_limit(self):
         arglist = [
-            '--limit', '1',
+            '--limit',
+            '1',
         ]
         verifylist = [
             ('limit', 1),
@@ -585,10 +618,12 @@ class TestKeypairList(TestKeypair):
         self.sdk_client.keypairs.assert_called_with(limit=1)
 
     @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False))
+        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
+    )
     def test_keypair_list_with_limit_pre_v235(self):
         arglist = [
-            '--limit', '1',
+            '--limit',
+            '1',
         ]
         verifylist = [
             ('limit', 1),
@@ -596,18 +631,20 @@ class TestKeypairList(TestKeypair):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
         self.assertIn(
-            '--os-compute-api-version 2.35 or greater is required', str(ex))
+            '--os-compute-api-version 2.35 or greater is required', str(ex)
+        )
 
     @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True))
+        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=True)
+    )
     def test_keypair_list_with_marker(self):
         arglist = [
-            '--marker', 'test_kp',
+            '--marker',
+            'test_kp',
         ]
         verifylist = [
             ('marker', 'test_kp'),
@@ -619,10 +656,12 @@ class TestKeypairList(TestKeypair):
         self.sdk_client.keypairs.assert_called_with(marker='test_kp')
 
     @mock.patch.object(
-        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False))
+        sdk_utils, 'supports_microversion', new=mock.Mock(return_value=False)
+    )
     def test_keypair_list_with_marker_pre_v235(self):
         arglist = [
-            '--marker', 'test_kp',
+            '--marker',
+            'test_kp',
         ]
         verifylist = [
             ('marker', 'test_kp'),
@@ -630,89 +669,78 @@ class TestKeypairList(TestKeypair):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         ex = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
 
         self.assertIn(
-            '--os-compute-api-version 2.35 or greater is required', str(ex))
+            '--os-compute-api-version 2.35 or greater is required', str(ex)
+        )
 
 
 class TestKeypairShow(TestKeypair):
-
-    keypair = compute_fakes.FakeKeypair.create_one_keypair()
-
     def setUp(self):
-        super(TestKeypairShow, self).setUp()
+        super().setUp()
 
-        self.sdk_client.find_keypair.return_value = self.keypair
+        self.columns = (
+            'created_at',
+            'fingerprint',
+            'id',
+            'is_deleted',
+            'name',
+            'private_key',
+            'type',
+            'user_id',
+        )
 
         self.cmd = keypair.ShowKeypair(self.app, None)
 
-        self.columns = (
-            "fingerprint",
-            "name",
-            "type",
-            "user_id"
-        )
-
-        self.data = (
-            self.keypair.fingerprint,
-            self.keypair.name,
-            self.keypair.type,
-            self.keypair.user_id
-        )
-
     def test_keypair_show_no_options(self):
-
         arglist = []
         verifylist = []
 
         # Missing required args should boil here
-        self.assertRaises(tests_utils.ParserException, self.check_parser,
-                          self.cmd, arglist, verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_keypair_show(self):
-        # overwrite the setup one because we want to omit private_key
-        self.keypair = compute_fakes.FakeKeypair.create_one_keypair(
-            no_pri=True)
+        self.keypair = compute_fakes.create_one_keypair()
         self.sdk_client.find_keypair.return_value = self.keypair
 
         self.data = (
+            self.keypair.created_at,
             self.keypair.fingerprint,
+            self.keypair.id,
+            self.keypair.is_deleted,
             self.keypair.name,
+            self.keypair.private_key,
             self.keypair.type,
-            self.keypair.user_id
+            self.keypair.user_id,
         )
 
-        arglist = [
-            self.keypair.name
-        ]
-        verifylist = [
-            ('name', self.keypair.name)
-        ]
+        arglist = [self.keypair.name]
+        verifylist = [('name', self.keypair.name)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
         self.sdk_client.find_keypair.assert_called_with(
-            self.keypair.name,
-            ignore_missing=False
+            self.keypair.name, ignore_missing=False
         )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
     def test_keypair_show_public(self):
+        self.keypair = compute_fakes.create_one_keypair()
+        self.sdk_client.find_keypair.return_value = self.keypair
 
-        arglist = [
-            '--public-key',
-            self.keypair.name
-        ]
-        verifylist = [
-            ('public_key', True),
-            ('name', self.keypair.name)
-        ]
+        arglist = ['--public-key', self.keypair.name]
+        verifylist = [('public_key', True), ('name', self.keypair.name)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -723,26 +751,28 @@ class TestKeypairShow(TestKeypair):
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=True)
     def test_keypair_show_with_user(self, sm_mock):
-
-        # overwrite the setup one because we want to omit private_key
-        self.keypair = compute_fakes.FakeKeypair.create_one_keypair(
-            no_pri=True)
+        self.keypair = compute_fakes.create_one_keypair()
         self.sdk_client.find_keypair.return_value = self.keypair
 
         self.data = (
+            self.keypair.created_at,
             self.keypair.fingerprint,
+            self.keypair.id,
+            self.keypair.is_deleted,
             self.keypair.name,
+            self.keypair.private_key,
             self.keypair.type,
-            self.keypair.user_id
+            self.keypair.user_id,
         )
 
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
             self.keypair.name,
         ]
         verifylist = [
             ('user', identity_fakes.user_name),
-            ('name', self.keypair.name)
+            ('name', self.keypair.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -752,7 +782,7 @@ class TestKeypairShow(TestKeypair):
         self.sdk_client.find_keypair.assert_called_with(
             self.keypair.name,
             ignore_missing=False,
-            user_id=identity_fakes.user_id
+            user_id=identity_fakes.user_id,
         )
 
         self.assertEqual(self.columns, columns)
@@ -760,20 +790,24 @@ class TestKeypairShow(TestKeypair):
 
     @mock.patch.object(sdk_utils, 'supports_microversion', return_value=False)
     def test_keypair_show_with_user_pre_v210(self, sm_mock):
-
+        self.keypair = compute_fakes.create_one_keypair()
         arglist = [
-            '--user', identity_fakes.user_name,
+            '--user',
+            identity_fakes.user_name,
             self.keypair.name,
         ]
         verifylist = [
             ('user', identity_fakes.user_name),
-            ('name', self.keypair.name)
+            ('name', self.keypair.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         ex = self.assertRaises(
             exceptions.CommandError,
             self.cmd.take_action,
-            parsed_args)
+            parsed_args,
+        )
         self.assertIn(
-            '--os-compute-api-version 2.10 or greater is required', str(ex))
+            '--os-compute-api-version 2.10 or greater is required',
+            str(ex),
+        )
