@@ -17,31 +17,29 @@ from unittest import mock
 from unittest.mock import call
 
 from novaclient import api_versions
+from openstack import utils as sdk_utils
 from osc_lib import exceptions
-import six
 
 from openstackclient.compute.v2 import service
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
 
 
 class TestService(compute_fakes.TestComputev2):
-
     def setUp(self):
         super(TestService, self).setUp()
 
-        # Get a shortcut to the ServiceManager Mock
-        self.service_mock = self.app.client_manager.compute.services
-        self.service_mock.reset_mock()
+        self.app.client_manager.sdk_connection = mock.Mock()
+        self.app.client_manager.sdk_connection.compute = mock.Mock()
+        self.sdk_client = self.app.client_manager.sdk_connection.compute
 
 
 class TestServiceDelete(TestService):
-
-    services = compute_fakes.FakeService.create_services(count=2)
+    services = compute_fakes.create_services(count=2)
 
     def setUp(self):
         super(TestServiceDelete, self).setUp()
 
-        self.service_mock.delete.return_value = None
+        self.sdk_client.delete_service.return_value = None
 
         # Get the command object to test
         self.cmd = service.DeleteService(self.app, None)
@@ -57,8 +55,8 @@ class TestServiceDelete(TestService):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.service_mock.delete.assert_called_with(
-            self.services[0].binary,
+        self.sdk_client.delete_service.assert_called_with(
+            self.services[0].binary, ignore_missing=False
         )
         self.assertIsNone(result)
 
@@ -75,8 +73,8 @@ class TestServiceDelete(TestService):
 
         calls = []
         for s in self.services:
-            calls.append(call(s.binary))
-        self.service_mock.delete.assert_has_calls(calls)
+            calls.append(call(s.binary, ignore_missing=False))
+        self.sdk_client.delete_service.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_multi_services_delete_with_exception(self):
@@ -84,14 +82,12 @@ class TestServiceDelete(TestService):
             self.services[0].binary,
             'unexist_service',
         ]
-        verifylist = [
-            ('service', arglist)
-        ]
+        verifylist = [('service', arglist)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         delete_mock_result = [None, exceptions.CommandError]
-        self.service_mock.delete = (
-            mock.Mock(side_effect=delete_mock_result)
+        self.sdk_client.delete_service = mock.Mock(
+            side_effect=delete_mock_result
         )
 
         try:
@@ -99,15 +95,19 @@ class TestServiceDelete(TestService):
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
             self.assertEqual(
-                '1 of 2 compute services failed to delete.', str(e))
+                '1 of 2 compute services failed to delete.', str(e)
+            )
 
-        self.service_mock.delete.assert_any_call(self.services[0].binary)
-        self.service_mock.delete.assert_any_call('unexist_service')
+        self.sdk_client.delete_service.assert_any_call(
+            self.services[0].binary, ignore_missing=False
+        )
+        self.sdk_client.delete_service.assert_any_call(
+            'unexist_service', ignore_missing=False
+        )
 
 
 class TestServiceList(TestService):
-
-    service = compute_fakes.FakeService.create_one_service()
+    service = compute_fakes.create_one_service()
 
     columns = (
         'ID',
@@ -118,33 +118,35 @@ class TestServiceList(TestService):
         'State',
         'Updated At',
     )
-    columns_long = columns + (
-        'Disabled Reason',
-    )
+    columns_long = columns + ('Disabled Reason',)
 
-    data = [(
-        service.id,
-        service.binary,
-        service.host,
-        service.zone,
-        service.status,
-        service.state,
-        service.updated_at,
-    )]
-    data_long = [data[0] + (service.disabled_reason, )]
+    data = [
+        (
+            service.id,
+            service.binary,
+            service.host,
+            service.availability_zone,
+            service.status,
+            service.state,
+            service.updated_at,
+        )
+    ]
+    data_long = [data[0] + (service.disabled_reason,)]
 
     def setUp(self):
         super(TestServiceList, self).setUp()
 
-        self.service_mock.list.return_value = [self.service]
+        self.sdk_client.services.return_value = [self.service]
 
         # Get the command object to test
         self.cmd = service.ListService(self.app, None)
 
     def test_service_list(self):
         arglist = [
-            '--host', self.service.host,
-            '--service', self.service.binary,
+            '--host',
+            self.service.host,
+            '--service',
+            self.service.binary,
         ]
         verifylist = [
             ('host', self.service.host),
@@ -157,24 +159,29 @@ class TestServiceList(TestService):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.service_mock.list.assert_called_with(
-            self.service.host,
-            self.service.binary,
+        self.sdk_client.services.assert_called_with(
+            host=self.service.host,
+            binary=self.service.binary,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
-    def test_service_list_with_long_option(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_list_with_long_option(self, sm_mock):
+        sm_mock.return_value = False
+
         arglist = [
-            '--host', self.service.host,
-            '--service', self.service.binary,
-            '--long'
+            '--host',
+            self.service.host,
+            '--service',
+            self.service.binary,
+            '--long',
         ]
         verifylist = [
             ('host', self.service.host),
             ('service', self.service.binary),
-            ('long', True)
+            ('long', True),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -183,28 +190,67 @@ class TestServiceList(TestService):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.service_mock.list.assert_called_with(
-            self.service.host,
-            self.service.binary,
+        self.sdk_client.services.assert_called_with(
+            host=self.service.host,
+            binary=self.service.binary,
         )
 
         self.assertEqual(self.columns_long, columns)
         self.assertEqual(self.data_long, list(data))
 
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_list_with_long_option_2_11(self, sm_mock):
+        sm_mock.return_value = True
+
+        arglist = [
+            '--host',
+            self.service.host,
+            '--service',
+            self.service.binary,
+            '--long',
+        ]
+        verifylist = [
+            ('host', self.service.host),
+            ('service', self.service.binary),
+            ('long', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.app.client_manager.compute.api_version = api_versions.APIVersion(
+            '2.11'
+        )
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.sdk_client.services.assert_called_with(
+            host=self.service.host,
+            binary=self.service.binary,
+        )
+
+        # In 2.11 there is also a forced_down column.
+        columns_long = self.columns_long + ('Forced Down',)
+        data_long = [self.data_long[0] + (self.service.is_forced_down,)]
+
+        self.assertEqual(columns_long, columns)
+        self.assertEqual(data_long, list(data))
+
 
 class TestServiceSet(TestService):
-
     def setUp(self):
         super(TestServiceSet, self).setUp()
 
-        self.service = compute_fakes.FakeService.create_one_service()
+        self.service = compute_fakes.create_one_service()
 
-        self.service_mock.enable.return_value = self.service
-        self.service_mock.disable.return_value = self.service
+        self.sdk_client.enable_service.return_value = self.service
+        self.sdk_client.disable_service.return_value = self.service
 
         self.cmd = service.SetService(self.app, None)
 
-    def test_set_nothing(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_set_nothing(self, sm_mock):
+        sm_mock.return_value = False
         arglist = [
             self.service.host,
             self.service.binary,
@@ -216,12 +262,13 @@ class TestServiceSet(TestService):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
-        self.service_mock.enable.assert_not_called()
-        self.service_mock.disable.assert_not_called()
-        self.service_mock.disable_log_reason.assert_not_called()
+        self.sdk_client.enable_service.assert_not_called()
+        self.sdk_client.disable_service.assert_not_called()
         self.assertIsNone(result)
 
-    def test_service_set_enable(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_enable(self, sm_mock):
+        sm_mock.return_value = False
         arglist = [
             '--enable',
             self.service.host,
@@ -236,13 +283,14 @@ class TestServiceSet(TestService):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.service_mock.enable.assert_called_with(
-            self.service.host,
-            self.service.binary
+        self.sdk_client.enable_service.assert_called_with(
+            None, self.service.host, self.service.binary
         )
         self.assertIsNone(result)
 
-    def test_service_set_disable(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_disable(self, sm_mock):
+        sm_mock.return_value = False
         arglist = [
             '--disable',
             self.service.host,
@@ -257,17 +305,19 @@ class TestServiceSet(TestService):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.service_mock.disable.assert_called_with(
-            self.service.host,
-            self.service.binary
+        self.sdk_client.disable_service.assert_called_with(
+            None, self.service.host, self.service.binary, None
         )
         self.assertIsNone(result)
 
-    def test_service_set_disable_with_reason(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_disable_with_reason(self, sm_mock):
+        sm_mock.return_value = False
         reason = 'earthquake'
         arglist = [
             '--disable',
-            '--disable-reason', reason,
+            '--disable-reason',
+            reason,
             self.service.host,
             self.service.binary,
         ]
@@ -281,17 +331,18 @@ class TestServiceSet(TestService):
 
         result = self.cmd.take_action(parsed_args)
 
-        self.service_mock.disable_log_reason.assert_called_with(
-            self.service.host,
-            self.service.binary,
-            reason
+        self.sdk_client.disable_service.assert_called_with(
+            None, self.service.host, self.service.binary, reason
         )
         self.assertIsNone(result)
 
-    def test_service_set_only_with_disable_reason(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_only_with_disable_reason(self, sm_mock):
+        sm_mock.return_value = False
         reason = 'earthquake'
         arglist = [
-            '--disable-reason', reason,
+            '--disable-reason',
+            reason,
             self.service.host,
             self.service.binary,
         ]
@@ -305,14 +356,20 @@ class TestServiceSet(TestService):
             self.cmd.take_action(parsed_args)
             self.fail("CommandError should be raised.")
         except exceptions.CommandError as e:
-            self.assertEqual("Cannot specify option --disable-reason without "
-                             "--disable specified.", str(e))
+            self.assertEqual(
+                "Cannot specify option --disable-reason without "
+                "--disable specified.",
+                str(e),
+            )
 
-    def test_service_set_enable_with_disable_reason(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_enable_with_disable_reason(self, sm_mock):
+        sm_mock.return_value = False
         reason = 'earthquake'
         arglist = [
             '--enable',
-            '--disable-reason', reason,
+            '--disable-reason',
+            reason,
             self.service.host,
             self.service.binary,
         ]
@@ -327,10 +384,15 @@ class TestServiceSet(TestService):
             self.cmd.take_action(parsed_args)
             self.fail("CommandError should be raised.")
         except exceptions.CommandError as e:
-            self.assertEqual("Cannot specify option --disable-reason without "
-                             "--disable specified.", str(e))
+            self.assertEqual(
+                "Cannot specify option --disable-reason without "
+                "--disable specified.",
+                str(e),
+            )
 
-    def test_service_set_state_up(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_state_up(self, sm_mock):
+        sm_mock.side_effect = [False, True]
         arglist = [
             '--up',
             self.service.host,
@@ -342,16 +404,17 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.11')
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.force_down.assert_called_once_with(
-            self.service.host, self.service.binary, False)
-        self.assertNotCalled(self.service_mock.enable)
-        self.assertNotCalled(self.service_mock.disable)
+        self.sdk_client.update_service_forced_down.assert_called_once_with(
+            None, self.service.host, self.service.binary, False
+        )
+        self.assertNotCalled(self.sdk_client.enable_service)
+        self.assertNotCalled(self.sdk_client.disable_service)
         self.assertIsNone(result)
 
-    def test_service_set_state_down(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_state_down(self, sm_mock):
+        sm_mock.side_effect = [False, True]
         arglist = [
             '--down',
             self.service.host,
@@ -363,16 +426,17 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.11')
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.force_down.assert_called_once_with(
-            self.service.host, self.service.binary, True)
-        self.assertNotCalled(self.service_mock.enable)
-        self.assertNotCalled(self.service_mock.disable)
+        self.sdk_client.update_service_forced_down.assert_called_once_with(
+            None, self.service.host, self.service.binary, True
+        )
+        self.assertNotCalled(self.sdk_client.enable_service)
+        self.assertNotCalled(self.sdk_client.disable_service)
         self.assertIsNone(result)
 
-    def test_service_set_enable_and_state_down(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_enable_and_state_down(self, sm_mock):
+        sm_mock.side_effect = [False, True]
         arglist = [
             '--enable',
             '--down',
@@ -386,16 +450,18 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.11')
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.enable.assert_called_once_with(
-            self.service.host, self.service.binary)
-        self.service_mock.force_down.assert_called_once_with(
-            self.service.host, self.service.binary, True)
+        self.sdk_client.enable_service.assert_called_once_with(
+            None, self.service.host, self.service.binary
+        )
+        self.sdk_client.update_service_forced_down.assert_called_once_with(
+            None, self.service.host, self.service.binary, True
+        )
         self.assertIsNone(result)
 
-    def test_service_set_enable_and_state_down_with_exception(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_enable_and_state_down_with_exception(self, sm_mock):
+        sm_mock.side_effect = [False, True]
         arglist = [
             '--enable',
             '--down',
@@ -410,18 +476,21 @@ class TestServiceSet(TestService):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.11')
-        with mock.patch.object(self.service_mock, 'enable',
-                               side_effect=Exception()):
-            self.assertRaises(exceptions.CommandError,
-                              self.cmd.take_action, parsed_args)
-            self.service_mock.force_down.assert_called_once_with(
-                self.service.host, self.service.binary, True)
+        with mock.patch.object(
+            self.sdk_client, 'enable_service', side_effect=Exception()
+        ):
+            self.assertRaises(
+                exceptions.CommandError, self.cmd.take_action, parsed_args
+            )
+            self.sdk_client.update_service_forced_down.assert_called_once_with(
+                None, self.service.host, self.service.binary, True
+            )
 
-    def test_service_set_2_53_disable_down(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_2_53_disable_down(self, sm_mock):
         # Tests disabling and forcing down a compute service with microversion
         # 2.53 which requires looking up the service by host and binary.
+        sm_mock.return_value = True
         arglist = [
             '--disable',
             '--down',
@@ -435,22 +504,27 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.53')
         service_id = '339478d0-0b95-4a94-be63-d5be05dfeb1c'
-        self.service_mock.list.return_value = [mock.Mock(id=service_id)]
+        self.sdk_client.services.return_value = [mock.Mock(id=service_id)]
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.disable.assert_called_once_with(service_id)
-        self.service_mock.force_down.assert_called_once_with(service_id, True)
+        self.sdk_client.disable_service.assert_called_once_with(
+            service_id, self.service.host, self.service.binary, None
+        )
+        self.sdk_client.update_service_forced_down.assert_called_once_with(
+            service_id, self.service.host, self.service.binary, True
+        )
         self.assertIsNone(result)
 
-    def test_service_set_2_53_disable_reason(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_2_53_disable_reason(self, sm_mock):
         # Tests disabling with reason a compute service with microversion
         # 2.53 which requires looking up the service by host and binary.
+        sm_mock.return_value = True
         reason = 'earthquake'
         arglist = [
             '--disable',
-            '--disable-reason', reason,
+            '--disable-reason',
+            reason,
             self.service.host,
             self.service.binary,
         ]
@@ -461,18 +535,19 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.53')
         service_id = '339478d0-0b95-4a94-be63-d5be05dfeb1c'
-        self.service_mock.list.return_value = [mock.Mock(id=service_id)]
+        self.sdk_client.services.return_value = [mock.Mock(id=service_id)]
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.disable_log_reason.assert_called_once_with(
-            service_id, reason)
+        self.sdk_client.disable_service.assert_called_once_with(
+            service_id, self.service.host, self.service.binary, reason
+        )
         self.assertIsNone(result)
 
-    def test_service_set_2_53_enable_up(self):
+    @mock.patch.object(sdk_utils, 'supports_microversion')
+    def test_service_set_2_53_enable_up(self, sm_mock):
         # Tests enabling and bringing up a compute service with microversion
         # 2.53 which requires looking up the service by host and binary.
+        sm_mock.return_value = True
         arglist = [
             '--enable',
             '--up',
@@ -486,30 +561,45 @@ class TestServiceSet(TestService):
             ('service', self.service.binary),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        self.app.client_manager.compute.api_version = api_versions.APIVersion(
-            '2.53')
         service_id = '339478d0-0b95-4a94-be63-d5be05dfeb1c'
-        self.service_mock.list.return_value = [mock.Mock(id=service_id)]
+        self.sdk_client.services.return_value = [mock.Mock(id=service_id)]
         result = self.cmd.take_action(parsed_args)
-        self.service_mock.enable.assert_called_once_with(service_id)
-        self.service_mock.force_down.assert_called_once_with(service_id, False)
+        self.sdk_client.enable_service.assert_called_once_with(
+            service_id, self.service.host, self.service.binary
+        )
+        self.sdk_client.update_service_forced_down.assert_called_once_with(
+            service_id, self.service.host, self.service.binary, False
+        )
         self.assertIsNone(result)
 
     def test_service_set_find_service_by_host_and_binary_no_results(self):
         # Tests that no compute services are found by host and binary.
-        self.service_mock.list.return_value = []
-        ex = self.assertRaises(exceptions.CommandError,
-                               self.cmd._find_service_by_host_and_binary,
-                               self.service_mock, 'fake-host', 'nova-compute')
-        self.assertIn('Compute service for host "fake-host" and binary '
-                      '"nova-compute" not found.', six.text_type(ex))
+        self.sdk_client.services.return_value = []
+        ex = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd._find_service_by_host_and_binary,
+            self.sdk_client,
+            'fake-host',
+            'nova-compute',
+        )
+        self.assertIn(
+            'Compute service for host "fake-host" and binary '
+            '"nova-compute" not found.',
+            str(ex),
+        )
 
     def test_service_set_find_service_by_host_and_binary_many_results(self):
         # Tests that more than one compute service is found by host and binary.
-        self.service_mock.list.return_value = [mock.Mock(), mock.Mock()]
-        ex = self.assertRaises(exceptions.CommandError,
-                               self.cmd._find_service_by_host_and_binary,
-                               self.service_mock, 'fake-host', 'nova-compute')
-        self.assertIn('Multiple compute services found for host "fake-host" '
-                      'and binary "nova-compute". Unable to proceed.',
-                      six.text_type(ex))
+        self.sdk_client.services.return_value = [mock.Mock(), mock.Mock()]
+        ex = self.assertRaises(
+            exceptions.CommandError,
+            self.cmd._find_service_by_host_and_binary,
+            self.sdk_client,
+            'fake-host',
+            'nova-compute',
+        )
+        self.assertIn(
+            'Multiple compute services found for host "fake-host" '
+            'and binary "nova-compute". Unable to proceed.',
+            str(ex),
+        )
