@@ -11,7 +11,6 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 import json
 import sys
@@ -30,8 +29,7 @@ REGION_NAME = "richie"
 INTERFACE = "catchy"
 VERSION = "3"
 
-TEST_RESPONSE_DICT = fixture.V2Token(token_id=AUTH_TOKEN,
-                                     user_name=USERNAME)
+TEST_RESPONSE_DICT = fixture.V2Token(token_id=AUTH_TOKEN, user_name=USERNAME)
 _s = TEST_RESPONSE_DICT.add_service('identity', name='keystone')
 _s.add_endpoint(AUTH_URL + ':5000/v2.0')
 _s = TEST_RESPONSE_DICT.add_service('network', name='neutron')
@@ -49,23 +47,7 @@ TEST_RESPONSE_DICT_V3.set_project_scope()
 TEST_VERSIONS = fixture.DiscoveryList(href=AUTH_URL)
 
 
-def to_unicode_dict(catalog_dict):
-    """Converts dict to unicode dict
-
-    """
-    if isinstance(catalog_dict, dict):
-        return {to_unicode_dict(key): to_unicode_dict(value)
-                for key, value in catalog_dict.items()}
-    elif isinstance(catalog_dict, list):
-        return [to_unicode_dict(element) for element in catalog_dict]
-    elif isinstance(catalog_dict, str):
-        return catalog_dict + u""
-    else:
-        return catalog_dict
-
-
 class FakeStdout(object):
-
     def __init__(self):
         self.content = []
 
@@ -80,7 +62,6 @@ class FakeStdout(object):
 
 
 class FakeLog(object):
-
     def __init__(self):
         self.messages = {}
 
@@ -101,7 +82,6 @@ class FakeLog(object):
 
 
 class FakeApp(object):
-
     def __init__(self, _stdout, _log):
         self.stdout = _stdout
         self.client_manager = None
@@ -118,7 +98,6 @@ class FakeOptions(object):
 
 
 class FakeClient(object):
-
     def __init__(self, **kwargs):
         self.endpoint = kwargs['endpoint']
         self.token = kwargs['token']
@@ -142,18 +121,29 @@ class FakeClientManager(object):
         self.network_endpoint_enabled = True
         self.compute_endpoint_enabled = True
         self.volume_endpoint_enabled = True
+        # The source of configuration. This is either 'cloud_config' (a
+        # clouds.yaml file) or 'global_env' ('OS_'-prefixed envvars)
+        self.configuration_type = 'cloud_config'
 
     def get_configuration(self):
-        return {
-            'auth': {
-                'username': USERNAME,
-                'password': PASSWORD,
-                'token': AUTH_TOKEN,
-            },
+        config = {
             'region': REGION_NAME,
             'identity_api_version': VERSION,
         }
 
+        if self.configuration_type == 'cloud_config':
+            config['auth'] = {
+                'username': USERNAME,
+                'password': PASSWORD,
+                'token': AUTH_TOKEN,
+            }
+        elif self.configuration_type == 'global_env':
+            config['username'] = USERNAME
+            config['password'] = PASSWORD
+            config['token'] = AUTH_TOKEN
+
+        return config
+
     def is_network_endpoint_enabled(self):
         return self.network_endpoint_enabled
 
@@ -165,7 +155,6 @@ class FakeClientManager(object):
 
 
 class FakeModule(object):
-
     def __init__(self, name, version):
         self.name = name
         self.__version__ = version
@@ -175,7 +164,6 @@ class FakeModule(object):
 
 
 class FakeResource(object):
-
     def __init__(self, manager=None, info=None, loaded=False, methods=None):
         """Set attributes and methods for a resource.
 
@@ -199,7 +187,7 @@ class FakeResource(object):
         self._loaded = loaded
 
     def _add_details(self, info):
-        for (k, v) in info.items():
+        for k, v in info.items():
             setattr(self, k, v)
 
     def _add_methods(self, methods):
@@ -210,13 +198,14 @@ class FakeResource(object):
         @value. When users access the attribute with (), @value will be
         returned, which looks like a function call.
         """
-        for (name, ret) in methods.items():
+        for name, ret in methods.items():
             method = mock.Mock(return_value=ret)
             setattr(self, name, method)
 
     def __repr__(self):
-        reprkeys = sorted(k for k in self.__dict__.keys() if k[0] != '_' and
-                          k != 'manager')
+        reprkeys = sorted(
+            k for k in self.__dict__.keys() if k[0] != '_' and k != 'manager'
+        )
         info = ", ".join("%s=%s" % (k, getattr(self, k)) for k in reprkeys)
         return "<%s %s>" % (self.__class__.__name__, info)
 
@@ -241,9 +230,9 @@ class FakeResource(object):
 
 
 class FakeResponse(requests.Response):
-
-    def __init__(self, headers=None, status_code=200,
-                 data=None, encoding=None):
+    def __init__(
+        self, headers=None, status_code=200, data=None, encoding=None
+    ):
         super(FakeResponse, self).__init__()
 
         headers = headers or {}
@@ -257,7 +246,6 @@ class FakeResponse(requests.Response):
 
 
 class FakeModel(dict):
-
     def __getattr__(self, key):
         try:
             return self[key]
