@@ -9,7 +9,6 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 import argparse
 import copy
@@ -18,11 +17,13 @@ from random import randint
 from unittest import mock
 import uuid
 
+from openstack.network.v2 import _proxy
 from openstack.network.v2 import address_group as _address_group
 from openstack.network.v2 import address_scope as _address_scope
 from openstack.network.v2 import agent as network_agent
 from openstack.network.v2 import auto_allocated_topology as allocated_topology
 from openstack.network.v2 import availability_zone as _availability_zone
+from openstack.network.v2 import extension as _extension
 from openstack.network.v2 import flavor as _flavor
 from openstack.network.v2 import local_ip as _local_ip
 from openstack.network.v2 import local_ip_association as _local_ip_association
@@ -61,40 +62,51 @@ RULE_TYPE_BANDWIDTH_LIMIT = 'bandwidth-limit'
 RULE_TYPE_DSCP_MARKING = 'dscp-marking'
 RULE_TYPE_MINIMUM_BANDWIDTH = 'minimum-bandwidth'
 RULE_TYPE_MINIMUM_PACKET_RATE = 'minimum-packet-rate'
-VALID_QOS_RULES = [RULE_TYPE_BANDWIDTH_LIMIT,
-                   RULE_TYPE_DSCP_MARKING,
-                   RULE_TYPE_MINIMUM_BANDWIDTH,
-                   RULE_TYPE_MINIMUM_PACKET_RATE]
-VALID_DSCP_MARKS = [0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32,
-                    34, 36, 38, 40, 46, 48, 56]
+VALID_QOS_RULES = [
+    RULE_TYPE_BANDWIDTH_LIMIT,
+    RULE_TYPE_DSCP_MARKING,
+    RULE_TYPE_MINIMUM_BANDWIDTH,
+    RULE_TYPE_MINIMUM_PACKET_RATE,
+]
+VALID_DSCP_MARKS = [
+    0,
+    8,
+    10,
+    12,
+    14,
+    16,
+    18,
+    20,
+    22,
+    24,
+    26,
+    28,
+    30,
+    32,
+    34,
+    36,
+    38,
+    40,
+    46,
+    48,
+    56,
+]
 
 
-class FakeNetworkV2Client(object):
-
-    def __init__(self, **kwargs):
-        self.session = mock.Mock()
-        self.extensions = mock.Mock()
-        self.extensions.resource_class = fakes.FakeResource(None, {})
-
-
-class TestNetworkV2(utils.TestCommand):
-
+class FakeClientMixin:
     def setUp(self):
-        super(TestNetworkV2, self).setUp()
+        super().setUp()
+
+        self.app.client_manager.network = mock.Mock(spec=_proxy.Proxy)
+        self.network_client = self.app.client_manager.network
+
+
+class TestNetworkV2(FakeClientMixin, utils.TestCommand):
+    def setUp(self):
+        super().setUp()
 
         self.namespace = argparse.Namespace()
 
-        self.app.client_manager.session = mock.Mock()
-
-        self.app.client_manager.network = FakeNetworkV2Client(
-            endpoint=fakes.AUTH_URL,
-            token=fakes.AUTH_TOKEN,
-        )
-
-        self.app.client_manager.sdk_connection = mock.Mock()
-        self.app.client_manager.sdk_connection.network = \
-            self.app.client_manager.network
-
         self.app.client_manager.identity = (
             identity_fakes_v3.FakeIdentityv3Client(
                 endpoint=fakes.AUTH_URL,
@@ -103,37 +115,30 @@ class TestNetworkV2(utils.TestCommand):
         )
 
 
-class FakeExtension(object):
-    """Fake one or more extension."""
+def create_one_extension(attrs=None):
+    """Create a fake extension.
 
-    @staticmethod
-    def create_one_extension(attrs=None):
-        """Create a fake extension.
+    :param Dictionary attrs:
+        A dictionary with all attributes
+    :return:
+        An Extension object with name, namespace, etc.
+    """
+    attrs = attrs or {}
 
-        :param Dictionary attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object with name, namespace, etc.
-        """
-        attrs = attrs or {}
+    # Set default attributes.
+    extension_info = {
+        'name': 'name-' + uuid.uuid4().hex,
+        'description': 'description-' + uuid.uuid4().hex,
+        'alias': 'Dystopian',
+        'links': [],
+        'updated_at': '2013-07-09T12:00:0-00:00',
+    }
 
-        # Set default attributes.
-        extension_info = {
-            'name': 'name-' + uuid.uuid4().hex,
-            'namespace': 'http://docs.openstack.org/network/',
-            'description': 'description-' + uuid.uuid4().hex,
-            'updated': '2013-07-09T12:00:0-00:00',
-            'alias': 'Dystopian',
-            'links': '[{"href":''"https://github.com/os/network", "type"}]',
-        }
+    # Overwrite default attributes.
+    extension_info.update(attrs)
 
-        # Overwrite default attributes.
-        extension_info.update(attrs)
-
-        extension = fakes.FakeResource(
-            info=copy.deepcopy(extension_info),
-            loaded=True)
-        return extension
+    extension = _extension.Extension(**extension_info)
+    return extension
 
 
 class FakeNetworkQosPolicy(object):
@@ -169,8 +174,8 @@ class FakeNetworkQosPolicy(object):
         qos_policy_attrs.update(attrs)
 
         qos_policy = fakes.FakeResource(
-            info=copy.deepcopy(qos_policy_attrs),
-            loaded=True)
+            info=copy.deepcopy(qos_policy_attrs), loaded=True
+        )
 
         # Set attributes with special mapping in OpenStack SDK.
         qos_policy.is_shared = qos_policy_attrs['shared']
@@ -191,7 +196,8 @@ class FakeNetworkQosPolicy(object):
         qos_policies = []
         for i in range(0, count):
             qos_policies.append(
-                FakeNetworkQosPolicy.create_one_qos_policy(attrs))
+                FakeNetworkQosPolicy.create_one_qos_policy(attrs)
+            )
 
         return qos_policies
 
@@ -240,8 +246,8 @@ class FakeNetworkSecGroup(object):
         }
 
         security_group = fakes.FakeResource(
-            info=copy.deepcopy(security_group_attrs),
-            loaded=True)
+            info=copy.deepcopy(security_group_attrs), loaded=True
+        )
 
         return security_group
 
@@ -285,8 +291,9 @@ class FakeNetworkQosRule(object):
         # Overwrite default attributes.
         qos_rule_attrs.update(attrs)
 
-        qos_rule = fakes.FakeResource(info=copy.deepcopy(qos_rule_attrs),
-                                      loaded=True)
+        qos_rule = fakes.FakeResource(
+            info=copy.deepcopy(qos_rule_attrs), loaded=True
+        )
 
         return qos_rule
 
@@ -322,7 +329,7 @@ class FakeNetworkQosRule(object):
             qos minimum bandwidth rules
         """
         if qos_rules is None:
-            qos_rules = (FakeNetworkQosRule.create_qos_rules(count))
+            qos_rules = FakeNetworkQosRule.create_qos_rules(count)
         return mock.Mock(side_effect=qos_rules)
 
 
@@ -350,8 +357,8 @@ class FakeNetworkQosRuleType(object):
         qos_rule_type_attrs.update(attrs)
 
         return fakes.FakeResource(
-            info=copy.deepcopy(qos_rule_type_attrs),
-            loaded=True)
+            info=copy.deepcopy(qos_rule_type_attrs), loaded=True
+        )
 
     @staticmethod
     def create_qos_rule_types(attrs=None, count=2):
@@ -367,7 +374,8 @@ class FakeNetworkQosRuleType(object):
         qos_rule_types = []
         for i in range(0, count):
             qos_rule_types.append(
-                FakeNetworkQosRuleType.create_one_qos_rule_type(attrs))
+                FakeNetworkQosRuleType.create_one_qos_rule_type(attrs)
+            )
 
         return qos_rule_types
 
@@ -408,8 +416,9 @@ class FakeRouter(object):
         # Overwrite default attributes.
         router_attrs.update(attrs)
 
-        router = fakes.FakeResource(info=copy.deepcopy(router_attrs),
-                                    loaded=True)
+        router = fakes.FakeResource(
+            info=copy.deepcopy(router_attrs), loaded=True
+        )
 
         # Set attributes with special mapping in OpenStack SDK.
         router.is_admin_state_up = router_attrs['admin_state_up']
@@ -485,8 +494,8 @@ class FakeSecurityGroup(object):
         security_group_attrs.update(attrs)
 
         security_group = fakes.FakeResource(
-            info=copy.deepcopy(security_group_attrs),
-            loaded=True)
+            info=copy.deepcopy(security_group_attrs), loaded=True
+        )
 
         return security_group
 
@@ -504,7 +513,8 @@ class FakeSecurityGroup(object):
         security_groups = []
         for i in range(0, count):
             security_groups.append(
-                FakeSecurityGroup.create_one_security_group(attrs))
+                FakeSecurityGroup.create_one_security_group(attrs)
+            )
 
         return security_groups
 
@@ -544,8 +554,8 @@ class FakeSecurityGroupRule(object):
 
         # Set default attributes.
         security_group_rule_attrs = {
-            'description': 'security-group-rule-description-' +
-                           uuid.uuid4().hex,
+            'description': 'security-group-rule-description-'
+            + uuid.uuid4().hex,
             'direction': 'ingress',
             'ether_type': 'IPv4',
             'id': 'security-group-rule-id-' + uuid.uuid4().hex,
@@ -564,8 +574,8 @@ class FakeSecurityGroupRule(object):
         security_group_rule_attrs.update(attrs)
 
         security_group_rule = fakes.FakeResource(
-            info=copy.deepcopy(security_group_rule_attrs),
-            loaded=True)
+            info=copy.deepcopy(security_group_rule_attrs), loaded=True
+        )
 
         return security_group_rule
 
@@ -583,7 +593,8 @@ class FakeSecurityGroupRule(object):
         security_group_rules = []
         for i in range(0, count):
             security_group_rules.append(
-                FakeSecurityGroupRule.create_one_security_group_rule(attrs))
+                FakeSecurityGroupRule.create_one_security_group_rule(attrs)
+            )
 
         return security_group_rules
 
@@ -604,7 +615,8 @@ class FakeSecurityGroupRule(object):
         """
         if security_group_rules is None:
             security_group_rules = (
-                FakeSecurityGroupRule.create_security_group_rules(count))
+                FakeSecurityGroupRule.create_security_group_rules(count)
+            )
         return mock.Mock(side_effect=security_group_rules)
 
 
@@ -649,8 +661,9 @@ class FakeSubnet(object):
         # Overwrite default attributes.
         subnet_attrs.update(attrs)
 
-        subnet = fakes.FakeResource(info=copy.deepcopy(subnet_attrs),
-                                    loaded=True)
+        subnet = fakes.FakeResource(
+            info=copy.deepcopy(subnet_attrs), loaded=True
+        )
 
         # Set attributes with special mappings in OpenStack SDK.
         subnet.is_dhcp_enabled = subnet_attrs['enable_dhcp']
@@ -731,8 +744,7 @@ class FakeFloatingIP(object):
         floating_ip_attrs.update(attrs)
 
         floating_ip = fakes.FakeResource(
-            info=copy.deepcopy(floating_ip_attrs),
-            loaded=True
+            info=copy.deepcopy(floating_ip_attrs), loaded=True
         )
 
         return floating_ip
@@ -793,8 +805,8 @@ class FakeNetworkMeter(object):
         meter_attrs.update(attrs)
 
         meter = fakes.FakeResource(
-            info=copy.deepcopy(meter_attrs),
-            loaded=True)
+            info=copy.deepcopy(meter_attrs), loaded=True
+        )
 
         return meter
 
@@ -804,16 +816,14 @@ class FakeNetworkMeter(object):
 
         meters = []
         for i in range(0, count):
-            meters.append(FakeNetworkMeter.
-                          create_one_meter(attrs))
+            meters.append(FakeNetworkMeter.create_one_meter(attrs))
         return meters
 
     @staticmethod
     def get_meter(meter=None, count=2):
         """Get a list of meters"""
         if meter is None:
-            meter = (FakeNetworkMeter.
-                     create_meter(count))
+            meter = FakeNetworkMeter.create_meter(count)
         return mock.Mock(side_effect=meter)
 
 
@@ -840,8 +850,8 @@ class FakeNetworkMeterRule(object):
         meter_rule_attrs.update(attrs)
 
         meter_rule = fakes.FakeResource(
-            info=copy.deepcopy(meter_rule_attrs),
-            loaded=True)
+            info=copy.deepcopy(meter_rule_attrs), loaded=True
+        )
 
         return meter_rule
 
@@ -851,16 +861,14 @@ class FakeNetworkMeterRule(object):
 
         meter_rules = []
         for i in range(0, count):
-            meter_rules.append(FakeNetworkMeterRule.
-                               create_one_rule(attrs))
+            meter_rules.append(FakeNetworkMeterRule.create_one_rule(attrs))
         return meter_rules
 
     @staticmethod
     def get_meter_rule(meter_rule=None, count=2):
         """Get a list of meter rules"""
         if meter_rule is None:
-            meter_rule = (FakeNetworkMeterRule.
-                          create_meter_rule(count))
+            meter_rule = FakeNetworkMeterRule.create_meter_rule(count)
         return mock.Mock(side_effect=meter_rule)
 
 
@@ -901,13 +909,13 @@ class FakeSubnetPool(object):
         subnet_pool_attrs.update(attrs)
 
         subnet_pool = fakes.FakeResource(
-            info=copy.deepcopy(subnet_pool_attrs),
-            loaded=True
+            info=copy.deepcopy(subnet_pool_attrs), loaded=True
         )
 
         # Set attributes with special mapping in OpenStack SDK.
-        subnet_pool.default_prefix_length = \
-            subnet_pool_attrs['default_prefixlen']
+        subnet_pool.default_prefix_length = subnet_pool_attrs[
+            'default_prefixlen'
+        ]
         subnet_pool.is_shared = subnet_pool_attrs['shared']
         subnet_pool.maximum_prefix_length = subnet_pool_attrs['max_prefixlen']
         subnet_pool.minimum_prefix_length = subnet_pool_attrs['min_prefixlen']
@@ -927,9 +935,7 @@ class FakeSubnetPool(object):
         """
         subnet_pools = []
         for i in range(0, count):
-            subnet_pools.append(
-                FakeSubnetPool.create_one_subnet_pool(attrs)
-            )
+            subnet_pools.append(FakeSubnetPool.create_one_subnet_pool(attrs))
 
         return subnet_pools
 
@@ -971,8 +977,8 @@ class FakeNetworkServiceProvider(object):
         service_provider.update(attrs)
 
         provider = fakes.FakeResource(
-            info=copy.deepcopy(service_provider),
-            loaded=True)
+            info=copy.deepcopy(service_provider), loaded=True
+        )
         provider.is_default = service_provider['default']
 
         return provider
@@ -983,9 +989,11 @@ class FakeNetworkServiceProvider(object):
 
         service_providers = []
         for i in range(0, count):
-            service_providers.append(FakeNetworkServiceProvider.
-                                     create_one_network_service_provider(
-                                         attrs))
+            service_providers.append(
+                FakeNetworkServiceProvider.create_one_network_service_provider(
+                    attrs
+                )
+            )
         return service_providers
 
 
@@ -1006,13 +1014,14 @@ class FakeQuota(object):
             'security_groups': 10,
             'security_group_rules': 100,
             'subnets': 20,
-            'subnet_pools': 30}
+            'subnet_pools': 30,
+        }
 
         quota_attrs.update(attrs)
 
         quota = fakes.FakeResource(
-            info=copy.deepcopy(quota_attrs),
-            loaded=True)
+            info=copy.deepcopy(quota_attrs), loaded=True
+        )
         return quota
 
     @staticmethod
@@ -1029,13 +1038,14 @@ class FakeQuota(object):
             'security_group': 30,
             'security_group_rule': 200,
             'subnet': 10,
-            'subnetpool': 20}
+            'subnetpool': 20,
+        }
 
         quota_attrs.update(attrs)
 
         quota = fakes.FakeResource(
-            info=copy.deepcopy(quota_attrs),
-            loaded=True)
+            info=copy.deepcopy(quota_attrs), loaded=True
+        )
         return quota
 
     @staticmethod
@@ -1052,25 +1062,28 @@ class FakeQuota(object):
             'security_groups': {'used': 0, 'reserved': 0, 'limit': 10},
             'security_group_rules': {'used': 0, 'reserved': 0, 'limit': 100},
             'subnets': {'used': 0, 'reserved': 0, 'limit': 20},
-            'subnet_pools': {'used': 0, 'reserved': 0, 'limit': 30}}
+            'subnet_pools': {'used': 0, 'reserved': 0, 'limit': 30},
+        }
 
         quota_attrs.update(attrs)
 
         quota = fakes.FakeResource(
-            info=copy.deepcopy(quota_attrs),
-            loaded=True)
+            info=copy.deepcopy(quota_attrs), loaded=True
+        )
         return quota
 
 
 class FakeFloatingIPPortForwarding(object):
-    """"Fake one or more Port forwarding"""
+    """Fake one or more Port forwarding"""
 
     @staticmethod
-    def create_one_port_forwarding(attrs=None):
+    def create_one_port_forwarding(attrs=None, use_range=False):
         """Create a fake Port Forwarding.
 
         :param Dictionary attrs:
             A dictionary with all attributes
+        :param Boolean use_range:
+            A boolean which defines if we will use ranges or not
         :return:
             A FakeResource object with name, id, etc.
         """
@@ -1084,42 +1097,61 @@ class FakeFloatingIPPortForwarding(object):
             'floatingip_id': floatingip_id,
             'internal_port_id': 'internal-port-id-' + uuid.uuid4().hex,
             'internal_ip_address': '192.168.1.2',
-            'internal_port': randint(1, 65535),
-            'external_port': randint(1, 65535),
             'protocol': 'tcp',
             'description': 'some description',
             'location': 'MUNCHMUNCHMUNCH',
         }
 
+        if use_range:
+            port_range = randint(0, 100)
+            internal_start = randint(1, 65535 - port_range)
+            internal_end = internal_start + port_range
+            internal_range = ':'.join(map(str, [internal_start, internal_end]))
+            external_start = randint(1, 65535 - port_range)
+            external_end = external_start + port_range
+            external_range = ':'.join(map(str, [external_start, external_end]))
+            port_forwarding_attrs['internal_port_range'] = internal_range
+            port_forwarding_attrs['external_port_range'] = external_range
+            port_forwarding_attrs['internal_port'] = None
+            port_forwarding_attrs['external_port'] = None
+        else:
+            port_forwarding_attrs['internal_port'] = randint(1, 65535)
+            port_forwarding_attrs['external_port'] = randint(1, 65535)
+            port_forwarding_attrs['internal_port_range'] = ''
+            port_forwarding_attrs['external_port_range'] = ''
+
         # Overwrite default attributes.
         port_forwarding_attrs.update(attrs)
 
         port_forwarding = fakes.FakeResource(
-            info=copy.deepcopy(port_forwarding_attrs),
-            loaded=True
+            info=copy.deepcopy(port_forwarding_attrs), loaded=True
         )
         return port_forwarding
 
     @staticmethod
-    def create_port_forwardings(attrs=None, count=2):
+    def create_port_forwardings(attrs=None, count=2, use_range=False):
         """Create multiple fake Port Forwarding.
 
-          :param Dictionary attrs:
-              A dictionary with all attributes
-          :param int count:
-              The number of Port Forwarding rule to fake
-          :return:
-              A list of FakeResource objects faking the Port Forwardings
-          """
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param int count:
+            The number of Port Forwarding rule to fake
+        :param Boolean use_range:
+            A boolean which defines if we will use ranges or not
+        :return:
+            A list of FakeResource objects faking the Port Forwardings
+        """
         port_forwardings = []
         for i in range(0, count):
             port_forwardings.append(
-                FakeFloatingIPPortForwarding.create_one_port_forwarding(attrs)
+                FakeFloatingIPPortForwarding.create_one_port_forwarding(
+                    attrs, use_range=use_range
+                )
             )
         return port_forwardings
 
     @staticmethod
-    def get_port_forwardings(port_forwardings=None, count=2):
+    def get_port_forwardings(port_forwardings=None, count=2, use_range=False):
         """Get a list of faked Port Forwardings.
 
         If port forwardings list is provided, then initialize the Mock object
@@ -1129,20 +1161,24 @@ class FakeFloatingIPPortForwarding(object):
             A list of FakeResource objects faking port forwardings
         :param int count:
             The number of Port Forwardings to fake
+        :param Boolean use_range:
+            A boolean which defines if we will use ranges or not
         :return:
             An iterable Mock object with side_effect set to a list of faked
             Port Forwardings
         """
         if port_forwardings is None:
             port_forwardings = (
-                FakeFloatingIPPortForwarding.create_port_forwardings(count)
+                FakeFloatingIPPortForwarding.create_port_forwardings(
+                    count, use_range=use_range
+                )
             )
 
         return mock.Mock(side_effect=port_forwardings)
 
 
 class FakeL3ConntrackHelper(object):
-    """"Fake one or more L3 conntrack helper"""
+    """Fake one or more L3 conntrack helper"""
 
     @staticmethod
     def create_one_l3_conntrack_helper(attrs=None):
@@ -1154,9 +1190,7 @@ class FakeL3ConntrackHelper(object):
             A FakeResource object with protocol, port, etc.
         """
         attrs = attrs or {}
-        router_id = (
-            attrs.get('router_id') or 'router-id-' + uuid.uuid4().hex
-        )
+        router_id = attrs.get('router_id') or 'router-id-' + uuid.uuid4().hex
         # Set default attributes.
         ct_attrs = {
             'id': uuid.uuid4().hex,
@@ -1170,10 +1204,7 @@ class FakeL3ConntrackHelper(object):
         # Overwrite default attributes.
         ct_attrs.update(attrs)
 
-        ct = fakes.FakeResource(
-            info=copy.deepcopy(ct_attrs),
-            loaded=True
-        )
+        ct = fakes.FakeResource(info=copy.deepcopy(ct_attrs), loaded=True)
         return ct
 
     @staticmethod
@@ -1210,8 +1241,8 @@ class FakeL3ConntrackHelper(object):
             L3 conntrack helpers
         """
         if ct_helpers is None:
-            ct_helpers = (
-                FakeL3ConntrackHelper.create_l3_conntrack_helpers(count)
+            ct_helpers = FakeL3ConntrackHelper.create_l3_conntrack_helpers(
+                count
             )
 
         return mock.Mock(side_effect=ct_helpers)
@@ -1432,7 +1463,8 @@ def create_one_ip_availability(attrs=None):
     network_ip_attrs.update(attrs)
 
     network_ip_availability = _ip_availability.NetworkIPAvailability(
-        **network_ip_attrs)
+        **network_ip_attrs
+    )
 
     return network_ip_availability
 
@@ -1660,8 +1692,10 @@ def create_one_network_segment_range(attrs=None):
         'physical_network': 'physical-network-name-' + fake_uuid,
         'minimum': 100,
         'maximum': 106,
-        'used': {104: '3312e4ba67864b2eb53f3f41432f8efc',
-                 106: '3312e4ba67864b2eb53f3f41432f8efc'},
+        'used': {
+            104: '3312e4ba67864b2eb53f3f41432f8efc',
+            106: '3312e4ba67864b2eb53f3f41432f8efc',
+        },
         'available': [100, 101, 102, 103, 105],
         'location': 'MUNCHMUNCHMUNCH',
     }
@@ -1669,8 +1703,9 @@ def create_one_network_segment_range(attrs=None):
     # Overwrite default attributes.
     network_segment_range_attrs.update(attrs)
 
-    network_segment_range = (
-        _segment_range.NetworkSegmentRange(**network_segment_range_attrs))
+    network_segment_range = _segment_range.NetworkSegmentRange(
+        **network_segment_range_attrs
+    )
 
     return network_segment_range
 
@@ -1720,8 +1755,13 @@ def create_one_port(attrs=None):
         'dns_domain': 'dns-domain-' + uuid.uuid4().hex,
         'dns_name': 'dns-name-' + uuid.uuid4().hex,
         'extra_dhcp_opts': [{}],
-        'fixed_ips': [{'ip_address': '10.0.0.3',
-                       'subnet_id': 'subnet-id-' + uuid.uuid4().hex}],
+        'fixed_ips': [
+            {
+                'ip_address': '10.0.0.3',
+                'subnet_id': 'subnet-id-' + uuid.uuid4().hex,
+            }
+        ],
+        'hints': {},
         'id': 'port-id-' + uuid.uuid4().hex,
         'mac_address': 'fa:16:3e:a9:4e:72',
         'name': 'port-name-' + uuid.uuid4().hex,
@@ -2039,9 +2079,9 @@ def create_one_local_ip_association(attrs=None):
     # Overwrite default attributes.
     local_ip_association_attrs.update(attrs)
 
-    local_ip_association = (
-        _local_ip_association.LocalIPAssociation(
-            **local_ip_association_attrs))
+    local_ip_association = _local_ip_association.LocalIPAssociation(
+        **local_ip_association_attrs
+    )
 
     return local_ip_association
 
@@ -2092,12 +2132,8 @@ def create_one_ndp_proxy(attrs=None):
         A FakeResource object with router_id, port_id, etc.
     """
     attrs = attrs or {}
-    router_id = (
-        attrs.get('router_id') or 'router-id-' + uuid.uuid4().hex
-    )
-    port_id = (
-        attrs.get('port_id') or 'port-id-' + uuid.uuid4().hex
-    )
+    router_id = attrs.get('router_id') or 'router-id-' + uuid.uuid4().hex
+    port_id = attrs.get('port_id') or 'port-id-' + uuid.uuid4().hex
     # Set default attributes.
     np_attrs = {
         'id': uuid.uuid4().hex,
@@ -2128,9 +2164,7 @@ def create_ndp_proxies(attrs=None, count=2):
     """
     ndp_proxies = []
     for i in range(0, count):
-        ndp_proxies.append(
-            create_one_ndp_proxy(attrs)
-        )
+        ndp_proxies.append(create_one_ndp_proxy(attrs))
     return ndp_proxies
 
 
@@ -2149,9 +2183,7 @@ def get_ndp_proxies(ndp_proxies=None, count=2):
         ndp proxy
     """
     if ndp_proxies is None:
-        ndp_proxies = (
-            create_ndp_proxies(count)
-        )
+        ndp_proxies = create_ndp_proxies(count)
     return mock.Mock(side_effect=ndp_proxies)
 
 
@@ -2174,10 +2206,13 @@ def create_one_trunk(attrs=None):
         'admin_state_up': True,
         'project_id': 'project-id-' + uuid.uuid4().hex,
         'status': 'ACTIVE',
-        'sub_ports': [{'port_id': 'subport-' +
-                       uuid.uuid4().hex,
-                       'segmentation_type': 'vlan',
-                       'segmentation_id': 100}],
+        'sub_ports': [
+            {
+                'port_id': 'subport-' + uuid.uuid4().hex,
+                'segmentation_type': 'vlan',
+                'segmentation_id': 100,
+            }
+        ],
     }
     # Overwrite default attributes.
     trunk_attrs.update(attrs)
