@@ -25,20 +25,19 @@ from openstackclient.volume.v1 import volume_type
 
 
 class TestType(volume_fakes.TestVolumev1):
-
     def setUp(self):
-        super(TestType, self).setUp()
+        super().setUp()
 
         self.types_mock = self.app.client_manager.volume.volume_types
         self.types_mock.reset_mock()
 
         self.encryption_types_mock = (
-            self.app.client_manager.volume.volume_encryption_types)
+            self.app.client_manager.volume.volume_encryption_types
+        )
         self.encryption_types_mock.reset_mock()
 
 
 class TestTypeCreate(TestType):
-
     columns = (
         'description',
         'id',
@@ -47,10 +46,10 @@ class TestTypeCreate(TestType):
     )
 
     def setUp(self):
-        super(TestTypeCreate, self).setUp()
+        super().setUp()
 
-        self.new_volume_type = volume_fakes.FakeType.create_one_type(
-            methods={'set_keys': {'myprop': 'myvalue'}}
+        self.new_volume_type = volume_fakes.create_one_volume_type(
+            methods={'set_keys': {'myprop': 'myvalue'}},
         )
         self.data = (
             self.new_volume_type.description,
@@ -78,7 +77,7 @@ class TestTypeCreate(TestType):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_create_with_encryption(self):
         encryption_info = {
@@ -87,11 +86,12 @@ class TestTypeCreate(TestType):
             'key_size': '128',
             'control_location': 'front-end',
         }
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs=encryption_info
+        encryption_type = volume_fakes.create_one_encryption_volume_type(
+            attrs=encryption_info,
+        )
+        self.new_volume_type = volume_fakes.create_one_volume_type(
+            attrs={'encryption': encryption_info},
         )
-        self.new_volume_type = volume_fakes.FakeType.create_one_type(
-            attrs={'encryption': encryption_info})
         self.types_mock.create.return_value = self.new_volume_type
         self.encryption_types_mock.create.return_value = encryption_type
         encryption_columns = (
@@ -109,10 +109,14 @@ class TestTypeCreate(TestType):
             self.new_volume_type.name,
         )
         arglist = [
-            '--encryption-provider', 'LuksEncryptor',
-            '--encryption-cipher', 'aes-xts-plain64',
-            '--encryption-key-size', '128',
-            '--encryption-control-location', 'front-end',
+            '--encryption-provider',
+            'LuksEncryptor',
+            '--encryption-cipher',
+            'aes-xts-plain64',
+            '--encryption-key-size',
+            '128',
+            '--encryption-control-location',
+            'front-end',
             self.new_volume_type.name,
         ]
         verifylist = [
@@ -139,30 +143,24 @@ class TestTypeCreate(TestType):
             body,
         )
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeDelete(TestType):
-
-    volume_types = volume_fakes.FakeType.create_types(count=2)
+    volume_types = volume_fakes.create_volume_types(count=2)
 
     def setUp(self):
-        super(TestTypeDelete, self).setUp()
+        super().setUp()
 
-        self.types_mock.get = volume_fakes.FakeType.get_types(
-            self.volume_types)
+        self.types_mock.get = volume_fakes.get_volume_types(self.volume_types)
         self.types_mock.delete.return_value = None
 
         # Get the command object to mock
         self.cmd = volume_type.DeleteVolumeType(self.app, None)
 
     def test_type_delete(self):
-        arglist = [
-            self.volume_types[0].id
-        ]
-        verifylist = [
-            ("volume_types", [self.volume_types[0].id])
-        ]
+        arglist = [self.volume_types[0].id]
+        verifylist = [("volume_types", [self.volume_types[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
@@ -199,17 +197,18 @@ class TestTypeDelete(TestType):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self.volume_types[0], exceptions.CommandError]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             try:
                 self.cmd.take_action(parsed_args)
                 self.fail('CommandError should be raised.')
             except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 volume types failed to delete.',
-                                 str(e))
+                self.assertEqual(
+                    '1 of 2 volume types failed to delete.', str(e)
+                )
 
-            find_mock.assert_any_call(
-                self.types_mock, self.volume_types[0].id)
+            find_mock.assert_any_call(self.types_mock, self.volume_types[0].id)
             find_mock.assert_any_call(self.types_mock, 'unexist_type')
 
             self.assertEqual(2, find_mock.call_count)
@@ -219,39 +218,37 @@ class TestTypeDelete(TestType):
 
 
 class TestTypeList(TestType):
-
-    volume_types = volume_fakes.FakeType.create_types()
+    volume_types = volume_fakes.create_volume_types()
 
     columns = [
         "ID",
         "Name",
         "Is Public",
     ]
-    columns_long = [
-        "ID",
-        "Name",
-        "Is Public",
-        "Properties"
-    ]
+    columns_long = ["ID", "Name", "Is Public", "Properties"]
 
     data = []
     for t in volume_types:
-        data.append((
-            t.id,
-            t.name,
-            t.is_public,
-        ))
+        data.append(
+            (
+                t.id,
+                t.name,
+                t.is_public,
+            )
+        )
     data_long = []
     for t in volume_types:
-        data_long.append((
-            t.id,
-            t.name,
-            t.is_public,
-            format_columns.DictColumn(t.extra_specs),
-        ))
+        data_long.append(
+            (
+                t.id,
+                t.name,
+                t.is_public,
+                format_columns.DictColumn(t.extra_specs),
+            )
+        )
 
     def setUp(self):
-        super(TestTypeList, self).setUp()
+        super().setUp()
 
         self.types_mock.list.return_value = self.volume_types
         self.encryption_types_mock.create.return_value = None
@@ -270,7 +267,7 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_type_list_with_options(self):
         arglist = [
@@ -284,11 +281,12 @@ class TestTypeList(TestType):
         columns, data = self.cmd.take_action(parsed_args)
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_type_list_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type(
-            attrs={'volume_type_id': self.volume_types[0].id})
+        encryption_type = volume_fakes.create_one_encryption_volume_type(
+            attrs={'volume_type_id': self.volume_types[0].id},
+        )
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
@@ -299,21 +297,25 @@ class TestTypeList(TestType):
             "Encryption",
         ]
         encryption_data = []
-        encryption_data.append((
-            self.volume_types[0].id,
-            self.volume_types[0].name,
-            self.volume_types[0].is_public,
-            volume_type.EncryptionInfoColumn(
+        encryption_data.append(
+            (
                 self.volume_types[0].id,
-                {self.volume_types[0].id: encryption_info}),
-        ))
-        encryption_data.append((
-            self.volume_types[1].id,
-            self.volume_types[1].name,
-            self.volume_types[1].is_public,
-            volume_type.EncryptionInfoColumn(
-                self.volume_types[1].id, {}),
-        ))
+                self.volume_types[0].name,
+                self.volume_types[0].is_public,
+                volume_type.EncryptionInfoColumn(
+                    self.volume_types[0].id,
+                    {self.volume_types[0].id: encryption_info},
+                ),
+            )
+        )
+        encryption_data.append(
+            (
+                self.volume_types[1].id,
+                self.volume_types[1].name,
+                self.volume_types[1].is_public,
+                volume_type.EncryptionInfoColumn(self.volume_types[1].id, {}),
+            )
+        )
 
         self.encryption_types_mock.list.return_value = [encryption_type]
         arglist = [
@@ -328,16 +330,16 @@ class TestTypeList(TestType):
         self.encryption_types_mock.list.assert_called_once_with()
         self.types_mock.list.assert_called_once_with()
         self.assertEqual(encryption_columns, columns)
-        self.assertListItemEqual(encryption_data, list(data))
+        self.assertCountEqual(encryption_data, list(data))
 
 
 class TestTypeSet(TestType):
-
-    volume_type = volume_fakes.FakeType.create_one_type(
-        methods={'set_keys': None})
+    volume_type = volume_fakes.create_one_volume_type(
+        methods={'set_keys': None},
+    )
 
     def setUp(self):
-        super(TestTypeSet, self).setUp()
+        super().setUp()
 
         self.types_mock.get.return_value = self.volume_type
 
@@ -359,7 +361,8 @@ class TestTypeSet(TestType):
 
     def test_type_set_property(self):
         arglist = [
-            '--property', 'myprop=myvalue',
+            '--property',
+            'myprop=myvalue',
             self.volume_type.id,
         ]
         verifylist = [
@@ -370,15 +373,20 @@ class TestTypeSet(TestType):
 
         result = self.cmd.take_action(parsed_args)
         self.volume_type.set_keys.assert_called_once_with(
-            {'myprop': 'myvalue'})
+            {'myprop': 'myvalue'}
+        )
         self.assertIsNone(result)
 
     def test_type_set_new_encryption(self):
         arglist = [
-            '--encryption-provider', 'LuksEncryptor',
-            '--encryption-cipher', 'aes-xts-plain64',
-            '--encryption-key-size', '128',
-            '--encryption-control-location', 'front-end',
+            '--encryption-provider',
+            'LuksEncryptor',
+            '--encryption-cipher',
+            'aes-xts-plain64',
+            '--encryption-key-size',
+            '128',
+            '--encryption-control-location',
+            'front-end',
             self.volume_type.id,
         ]
         verifylist = [
@@ -405,9 +413,12 @@ class TestTypeSet(TestType):
 
     def test_type_set_new_encryption_without_provider(self):
         arglist = [
-            '--encryption-cipher', 'aes-xts-plain64',
-            '--encryption-key-size', '128',
-            '--encryption-control-location', 'front-end',
+            '--encryption-cipher',
+            'aes-xts-plain64',
+            '--encryption-key-size',
+            '128',
+            '--encryption-control-location',
+            'front-end',
             self.volume_type.id,
         ]
         verifylist = [
@@ -421,15 +432,15 @@ class TestTypeSet(TestType):
             self.cmd.take_action(parsed_args)
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
-            self.assertEqual("Command Failed: One or more of"
-                             " the operations failed",
-                             str(e))
+            self.assertEqual(
+                "Command Failed: One or more of" " the operations failed",
+                str(e),
+            )
         self.encryption_types_mock.create.assert_not_called()
         self.encryption_types_mock.update.assert_not_called()
 
 
 class TestTypeShow(TestType):
-
     columns = (
         'description',
         'id',
@@ -439,15 +450,15 @@ class TestTypeShow(TestType):
     )
 
     def setUp(self):
-        super(TestTypeShow, self).setUp()
+        super().setUp()
 
-        self.volume_type = volume_fakes.FakeType.create_one_type()
+        self.volume_type = volume_fakes.create_one_volume_type()
         self.data = (
             self.volume_type.description,
             self.volume_type.id,
             True,
             self.volume_type.name,
-            format_columns.DictColumn(self.volume_type.extra_specs)
+            format_columns.DictColumn(self.volume_type.extra_specs),
         )
 
         self.types_mock.get.return_value = self.volume_type
@@ -456,9 +467,7 @@ class TestTypeShow(TestType):
         self.cmd = volume_type.ShowVolumeType(self.app, None)
 
     def test_type_show(self):
-        arglist = [
-            self.volume_type.id
-        ]
+        arglist = [self.volume_type.id]
         verifylist = [
             ("volume_type", self.volume_type.id),
             ("encryption_type", False),
@@ -469,18 +478,19 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_type_show_with_encryption(self):
-        encryption_type = volume_fakes.FakeType.create_one_encryption_type()
+        encryption_type = volume_fakes.create_one_encryption_volume_type()
         encryption_info = {
             'provider': 'LuksEncryptor',
             'cipher': None,
             'key_size': None,
             'control_location': 'front-end',
         }
-        self.volume_type = volume_fakes.FakeType.create_one_type(
-            attrs={'encryption': encryption_info})
+        self.volume_type = volume_fakes.create_one_volume_type(
+            attrs={'encryption': encryption_info},
+        )
         self.types_mock.get.return_value = self.volume_type
         self.encryption_types_mock.get.return_value = encryption_type
         encryption_columns = (
@@ -497,15 +507,12 @@ class TestTypeShow(TestType):
             self.volume_type.id,
             True,
             self.volume_type.name,
-            format_columns.DictColumn(self.volume_type.extra_specs)
+            format_columns.DictColumn(self.volume_type.extra_specs),
         )
-        arglist = [
-            '--encryption-type',
-            self.volume_type.id
-        ]
+        arglist = ['--encryption-type', self.volume_type.id]
         verifylist = [
             ('encryption_type', True),
-            ("volume_type", self.volume_type.id)
+            ("volume_type", self.volume_type.id),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -513,16 +520,16 @@ class TestTypeShow(TestType):
         self.types_mock.get.assert_called_with(self.volume_type.id)
         self.encryption_types_mock.get.assert_called_with(self.volume_type.id)
         self.assertEqual(encryption_columns, columns)
-        self.assertItemEqual(encryption_data, data)
+        self.assertCountEqual(encryption_data, data)
 
 
 class TestTypeUnset(TestType):
-
-    volume_type = volume_fakes.FakeType.create_one_type(
-        methods={'unset_keys': None})
+    volume_type = volume_fakes.create_one_volume_type(
+        methods={'unset_keys': None},
+    )
 
     def setUp(self):
-        super(TestTypeUnset, self).setUp()
+        super().setUp()
 
         self.types_mock.get.return_value = self.volume_type
 
@@ -531,8 +538,10 @@ class TestTypeUnset(TestType):
 
     def test_type_unset_property(self):
         arglist = [
-            '--property', 'property',
-            '--property', 'multi_property',
+            '--property',
+            'property',
+            '--property',
+            'multi_property',
             self.volume_type.id,
         ]
         verifylist = [
@@ -545,24 +554,29 @@ class TestTypeUnset(TestType):
 
         result = self.cmd.take_action(parsed_args)
         self.volume_type.unset_keys.assert_called_once_with(
-            ['property', 'multi_property'])
+            ['property', 'multi_property']
+        )
         self.encryption_types_mock.delete.assert_not_called()
         self.assertIsNone(result)
 
     def test_type_unset_failed_with_missing_volume_type_argument(self):
         arglist = [
-            '--property', 'property',
-            '--property', 'multi_property',
+            '--property',
+            'property',
+            '--property',
+            'multi_property',
         ]
         verifylist = [
             ('property', ['property', 'multi_property']),
         ]
 
-        self.assertRaises(tests_utils.ParserException,
-                          self.check_parser,
-                          self.cmd,
-                          arglist,
-                          verifylist)
+        self.assertRaises(
+            tests_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
+        )
 
     def test_type_unset_nothing(self):
         arglist = [
@@ -594,9 +608,8 @@ class TestTypeUnset(TestType):
 
 
 class TestColumns(TestType):
-
     def test_encryption_info_column_with_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.create_one_volume_type()
         type_id = fake_volume_type.id
 
         encryption_info = {
@@ -605,14 +618,16 @@ class TestColumns(TestType):
             'key_size': None,
             'control_location': 'front-end',
         }
-        col = volume_type.EncryptionInfoColumn(type_id,
-                                               {type_id: encryption_info})
-        self.assertEqual(utils.format_dict(encryption_info),
-                         col.human_readable())
+        col = volume_type.EncryptionInfoColumn(
+            type_id, {type_id: encryption_info}
+        )
+        self.assertEqual(
+            utils.format_dict(encryption_info), col.human_readable()
+        )
         self.assertEqual(encryption_info, col.machine_readable())
 
     def test_encryption_info_column_without_info(self):
-        fake_volume_type = volume_fakes.FakeType.create_one_type()
+        fake_volume_type = volume_fakes.create_one_volume_type()
         type_id = fake_volume_type.id
 
         col = volume_type.EncryptionInfoColumn(type_id, {})
