@@ -24,21 +24,19 @@ from openstackclient.volume.v2 import consistency_group
 
 
 class TestConsistencyGroup(volume_fakes.TestVolume):
-
     def setUp(self):
         super().setUp()
 
         # Get a shortcut to the TransferManager Mock
         self.consistencygroups_mock = (
-            self.app.client_manager.volume.consistencygroups)
+            self.app.client_manager.volume.consistencygroups
+        )
         self.consistencygroups_mock.reset_mock()
 
-        self.cgsnapshots_mock = (
-            self.app.client_manager.volume.cgsnapshots)
+        self.cgsnapshots_mock = self.app.client_manager.volume.cgsnapshots
         self.cgsnapshots_mock.reset_mock()
 
-        self.volumes_mock = (
-            self.app.client_manager.volume.volumes)
+        self.volumes_mock = self.app.client_manager.volume.volumes
         self.volumes_mock.reset_mock()
 
         self.types_mock = self.app.client_manager.volume.volume_types
@@ -46,17 +44,16 @@ class TestConsistencyGroup(volume_fakes.TestVolume):
 
 
 class TestConsistencyGroupAddVolume(TestConsistencyGroup):
-
     _consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
         super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self._consistency_group)
+        self.consistencygroups_mock.get.return_value = self._consistency_group
         # Get the command object to test
-        self.cmd = \
-            consistency_group.AddVolumeToConsistencyGroup(self.app, None)
+        self.cmd = consistency_group.AddVolumeToConsistencyGroup(
+            self.app, None
+        )
 
     def test_add_one_volume_to_consistency_group(self):
         volume = volume_fakes.create_one_volume()
@@ -78,8 +75,7 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
             'add_volumes': volume.id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
@@ -104,14 +100,14 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
             'add_volumes': volumes[0].id + ',' + volumes[1].id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     @mock.patch.object(consistency_group.LOG, 'error')
     def test_add_multiple_volumes_to_consistency_group_with_exception(
-        self, mock_error,
+        self,
+        mock_error,
     ):
         volume = volume_fakes.create_one_volume()
         arglist = [
@@ -126,20 +122,22 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [volume,
-                            exceptions.CommandError,
-                            self._consistency_group]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            volume,
+            exceptions.CommandError,
+            self._consistency_group,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             result = self.cmd.take_action(parsed_args)
             mock_error.assert_called_with("1 of 2 volumes failed to add.")
             self.assertIsNone(result)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self._consistency_group.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      volume.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      'unexist_volume')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self._consistency_group.id
+            )
+            find_mock.assert_any_call(self.volumes_mock, volume.id)
+            find_mock.assert_any_call(self.volumes_mock, 'unexist_volume')
             self.assertEqual(3, find_mock.call_count)
             self.consistencygroups_mock.update.assert_called_once_with(
                 self._consistency_group.id, add_volumes=volume.id
@@ -147,7 +145,6 @@ class TestConsistencyGroupAddVolume(TestConsistencyGroup):
 
 
 class TestConsistencyGroupCreate(TestConsistencyGroup):
-
     volume_type = volume_fakes.create_one_volume_type()
     new_consistency_group = volume_fakes.create_one_consistency_group()
     consistency_group_snapshot = (
@@ -176,22 +173,28 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
     def setUp(self):
         super().setUp()
         self.consistencygroups_mock.create.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.consistencygroups_mock.create_from_src.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.consistencygroups_mock.get.return_value = (
-            self.new_consistency_group)
+            self.new_consistency_group
+        )
         self.types_mock.get.return_value = self.volume_type
         self.cgsnapshots_mock.get.return_value = (
-            self.consistency_group_snapshot)
+            self.consistency_group_snapshot
+        )
 
         # Get the command object to test
         self.cmd = consistency_group.CreateConsistencyGroup(self.app, None)
 
     def test_consistency_group_create(self):
         arglist = [
-            '--volume-type', self.volume_type.id,
-            '--description', self.new_consistency_group.description,
+            '--volume-type',
+            self.volume_type.id,
+            '--description',
+            self.new_consistency_group.description,
             '--availability-zone',
             self.new_consistency_group.availability_zone,
             self.new_consistency_group.name,
@@ -199,16 +202,17 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
         verifylist = [
             ('volume_type', self.volume_type.id),
             ('description', self.new_consistency_group.description),
-            ('availability_zone',
-             self.new_consistency_group.availability_zone),
+            (
+                'availability_zone',
+                self.new_consistency_group.availability_zone,
+            ),
             ('name', self.new_consistency_group.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.types_mock.get.assert_called_once_with(
-            self.volume_type.id)
+        self.types_mock.get.assert_called_once_with(self.volume_type.id)
         self.consistencygroups_mock.get.assert_not_called()
         self.consistencygroups_mock.create.assert_called_once_with(
             self.volume_type.id,
@@ -222,23 +226,26 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
     def test_consistency_group_create_without_name(self):
         arglist = [
-            '--volume-type', self.volume_type.id,
-            '--description', self.new_consistency_group.description,
+            '--volume-type',
+            self.volume_type.id,
+            '--description',
+            self.new_consistency_group.description,
             '--availability-zone',
             self.new_consistency_group.availability_zone,
         ]
         verifylist = [
             ('volume_type', self.volume_type.id),
             ('description', self.new_consistency_group.description),
-            ('availability_zone',
-             self.new_consistency_group.availability_zone),
+            (
+                'availability_zone',
+                self.new_consistency_group.availability_zone,
+            ),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.types_mock.get.assert_called_once_with(
-            self.volume_type.id)
+        self.types_mock.get.assert_called_once_with(self.volume_type.id)
         self.consistencygroups_mock.get.assert_not_called()
         self.consistencygroups_mock.create.assert_called_once_with(
             self.volume_type.id,
@@ -252,12 +259,14 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
     def test_consistency_group_create_from_source(self):
         arglist = [
-            '--consistency-group-source', self.new_consistency_group.id,
-            '--description', self.new_consistency_group.description,
+            '--consistency-group-source',
+            self.new_consistency_group.id,
+            '--description',
+            self.new_consistency_group.description,
             self.new_consistency_group.name,
         ]
         verifylist = [
-            ('consistency_group_source', self.new_consistency_group.id),
+            ('source', self.new_consistency_group.id),
             ('description', self.new_consistency_group.description),
             ('name', self.new_consistency_group.name),
         ]
@@ -267,7 +276,8 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
         self.types_mock.get.assert_not_called()
         self.consistencygroups_mock.get.assert_called_once_with(
-            self.new_consistency_group.id)
+            self.new_consistency_group.id
+        )
         self.consistencygroups_mock.create_from_src.assert_called_with(
             None,
             self.new_consistency_group.id,
@@ -280,12 +290,14 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
     def test_consistency_group_create_from_snapshot(self):
         arglist = [
-            '--consistency-group-snapshot', self.consistency_group_snapshot.id,
-            '--description', self.new_consistency_group.description,
+            '--consistency-group-snapshot',
+            self.consistency_group_snapshot.id,
+            '--description',
+            self.new_consistency_group.description,
             self.new_consistency_group.name,
         ]
         verifylist = [
-            ('consistency_group_snapshot', self.consistency_group_snapshot.id),
+            ('snapshot', self.consistency_group_snapshot.id),
             ('description', self.new_consistency_group.description),
             ('name', self.new_consistency_group.name),
         ]
@@ -295,7 +307,8 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
         self.types_mock.get.assert_not_called()
         self.cgsnapshots_mock.get.assert_called_once_with(
-            self.consistency_group_snapshot.id)
+            self.consistency_group_snapshot.id
+        )
         self.consistencygroups_mock.create_from_src.assert_called_with(
             self.consistency_group_snapshot.id,
             None,
@@ -308,9 +321,7 @@ class TestConsistencyGroupCreate(TestConsistencyGroup):
 
 
 class TestConsistencyGroupDelete(TestConsistencyGroup):
-
-    consistency_groups =\
-        volume_fakes.create_consistency_groups(count=2)
+    consistency_groups = volume_fakes.create_consistency_groups(count=2)
 
     def setUp(self):
         super().setUp()
@@ -324,18 +335,15 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
         self.cmd = consistency_group.DeleteConsistencyGroup(self.app, None)
 
     def test_consistency_group_delete(self):
-        arglist = [
-            self.consistency_groups[0].id
-        ]
-        verifylist = [
-            ("consistency_groups", [self.consistency_groups[0].id])
-        ]
+        arglist = [self.consistency_groups[0].id]
+        verifylist = [("consistency_groups", [self.consistency_groups[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.delete.assert_called_with(
-            self.consistency_groups[0].id, False)
+            self.consistency_groups[0].id, False
+        )
         self.assertIsNone(result)
 
     def test_consistency_group_delete_with_force(self):
@@ -345,14 +353,15 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
         ]
         verifylist = [
             ('force', True),
-            ("consistency_groups", [self.consistency_groups[0].id])
+            ("consistency_groups", [self.consistency_groups[0].id]),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.delete.assert_called_with(
-            self.consistency_groups[0].id, True)
+            self.consistency_groups[0].id, True
+        )
         self.assertIsNone(result)
 
     def test_delete_multiple_consistency_groups(self):
@@ -383,21 +392,27 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [self.consistency_groups[0],
-                            exceptions.CommandError]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            self.consistency_groups[0],
+            exceptions.CommandError,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             try:
                 self.cmd.take_action(parsed_args)
                 self.fail('CommandError should be raised.')
             except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 consistency groups failed to delete.',
-                                 str(e))
+                self.assertEqual(
+                    '1 of 2 consistency groups failed to delete.', str(e)
+                )
 
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self.consistency_groups[0].id)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      'unexist_consistency_group')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self.consistency_groups[0].id
+            )
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, 'unexist_consistency_group'
+            )
 
             self.assertEqual(2, find_mock.call_count)
             self.consistencygroups_mock.delete.assert_called_once_with(
@@ -406,7 +421,6 @@ class TestConsistencyGroupDelete(TestConsistencyGroup):
 
 
 class TestConsistencyGroupList(TestConsistencyGroup):
-
     consistency_groups = volume_fakes.create_consistency_groups(count=2)
 
     columns = [
@@ -424,21 +438,25 @@ class TestConsistencyGroupList(TestConsistencyGroup):
     ]
     data = []
     for c in consistency_groups:
-        data.append((
-            c.id,
-            c.status,
-            c.name,
-        ))
+        data.append(
+            (
+                c.id,
+                c.status,
+                c.name,
+            )
+        )
     data_long = []
     for c in consistency_groups:
-        data_long.append((
-            c.id,
-            c.status,
-            c.availability_zone,
-            c.name,
-            c.description,
-            format_columns.ListColumn(c.volume_types)
-        ))
+        data_long.append(
+            (
+                c.id,
+                c.status,
+                c.availability_zone,
+                c.name,
+                c.description,
+                format_columns.ListColumn(c.volume_types),
+            )
+        )
 
     def setUp(self):
         super().setUp()
@@ -458,14 +476,13 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': False})
+            detailed=True, search_opts={'all_tenants': False}
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_consistency_group_list_with_all_project(self):
-        arglist = [
-            "--all-projects"
-        ]
+        arglist = ["--all-projects"]
         verifylist = [
             ("all_projects", True),
             ("long", False),
@@ -475,7 +492,8 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': True})
+            detailed=True, search_opts={'all_tenants': True}
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
@@ -492,23 +510,23 @@ class TestConsistencyGroupList(TestConsistencyGroup):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.consistencygroups_mock.list.assert_called_once_with(
-            detailed=True, search_opts={'all_tenants': False})
+            detailed=True, search_opts={'all_tenants': False}
+        )
         self.assertEqual(self.columns_long, columns)
         self.assertCountEqual(self.data_long, list(data))
 
 
 class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
-
     _consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
         super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self._consistency_group)
+        self.consistencygroups_mock.get.return_value = self._consistency_group
         # Get the command object to test
-        self.cmd = \
-            consistency_group.RemoveVolumeFromConsistencyGroup(self.app, None)
+        self.cmd = consistency_group.RemoveVolumeFromConsistencyGroup(
+            self.app, None
+        )
 
     def test_remove_one_volume_from_consistency_group(self):
         volume = volume_fakes.create_one_volume()
@@ -530,8 +548,7 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
             'remove_volumes': volume.id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
@@ -556,8 +573,7 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
             'remove_volumes': volumes[0].id + ',' + volumes[1].id,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self._consistency_group.id,
-            **kwargs
+            self._consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
@@ -579,20 +595,22 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        find_mock_result = [volume,
-                            exceptions.CommandError,
-                            self._consistency_group]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        find_mock_result = [
+            volume,
+            exceptions.CommandError,
+            self._consistency_group,
+        ]
+        with mock.patch.object(
+            utils, 'find_resource', side_effect=find_mock_result
+        ) as find_mock:
             result = self.cmd.take_action(parsed_args)
             mock_error.assert_called_with("1 of 2 volumes failed to remove.")
             self.assertIsNone(result)
-            find_mock.assert_any_call(self.consistencygroups_mock,
-                                      self._consistency_group.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      volume.id)
-            find_mock.assert_any_call(self.volumes_mock,
-                                      'unexist_volume')
+            find_mock.assert_any_call(
+                self.consistencygroups_mock, self._consistency_group.id
+            )
+            find_mock.assert_any_call(self.volumes_mock, volume.id)
+            find_mock.assert_any_call(self.volumes_mock, 'unexist_volume')
             self.assertEqual(3, find_mock.call_count)
             self.consistencygroups_mock.update.assert_called_once_with(
                 self._consistency_group.id, remove_volumes=volume.id
@@ -600,21 +618,20 @@ class TestConsistencyGroupRemoveVolume(TestConsistencyGroup):
 
 
 class TestConsistencyGroupSet(TestConsistencyGroup):
-
     consistency_group = volume_fakes.create_one_consistency_group()
 
     def setUp(self):
         super().setUp()
 
-        self.consistencygroups_mock.get.return_value = (
-            self.consistency_group)
+        self.consistencygroups_mock.get.return_value = self.consistency_group
         # Get the command object to test
         self.cmd = consistency_group.SetConsistencyGroup(self.app, None)
 
     def test_consistency_group_set_name(self):
         new_name = 'new_name'
         arglist = [
-            '--name', new_name,
+            '--name',
+            new_name,
             self.consistency_group.id,
         ]
         verifylist = [
@@ -631,15 +648,15 @@ class TestConsistencyGroupSet(TestConsistencyGroup):
             'name': new_name,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self.consistency_group.id,
-            **kwargs
+            self.consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_consistency_group_set_description(self):
         new_description = 'new_description'
         arglist = [
-            '--description', new_description,
+            '--description',
+            new_description,
             self.consistency_group.id,
         ]
         verifylist = [
@@ -656,8 +673,7 @@ class TestConsistencyGroupSet(TestConsistencyGroup):
             'description': new_description,
         }
         self.consistencygroups_mock.update.assert_called_once_with(
-            self.consistency_group.id,
-            **kwargs
+            self.consistency_group.id, **kwargs
         )
         self.assertIsNone(result)
 
@@ -690,15 +706,12 @@ class TestConsistencyGroupShow(TestConsistencyGroup):
         self.cmd = consistency_group.ShowConsistencyGroup(self.app, None)
 
     def test_consistency_group_show(self):
-        arglist = [
-            self.consistency_group.id
-        ]
-        verifylist = [
-            ("consistency_group", self.consistency_group.id)
-        ]
+        arglist = [self.consistency_group.id]
+        verifylist = [("consistency_group", self.consistency_group.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.consistencygroups_mock.get.assert_called_once_with(
-            self.consistency_group.id)
+            self.consistency_group.id
+        )
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
