@@ -16,15 +16,14 @@ from unittest import mock
 from unittest.mock import call
 
 from cinderclient import api_versions
+from openstack import utils as sdk_utils
 from osc_lib import exceptions
-from osc_lib import utils
 
 from openstackclient.tests.unit.volume.v2 import fakes as volume_fakes
 from openstackclient.volume.v2 import volume_backup
 
 
-class TestBackup(volume_fakes.TestVolume):
-
+class TestBackupLegacy(volume_fakes.TestVolume):
     def setUp(self):
         super().setUp()
 
@@ -38,56 +37,71 @@ class TestBackup(volume_fakes.TestVolume):
         self.restores_mock.reset_mock()
 
 
-class TestBackupCreate(TestBackup):
+class TestBackup(volume_fakes.TestVolume):
+    def setUp(self):
+        super().setUp()
 
+        self.app.client_manager.sdk_connection = mock.Mock()
+        self.app.client_manager.sdk_connection.volume = mock.Mock()
+        self.sdk_client = self.app.client_manager.sdk_connection.volume
+        patcher = mock.patch.object(
+            sdk_utils, 'supports_microversion', return_value=True
+        )
+        self.addCleanup(patcher.stop)
+        self.supports_microversion_mock = patcher.start()
+        self._set_mock_microversion(
+            self.app.client_manager.volume.api_version.get_string()
+        )
+
+    def _set_mock_microversion(self, mock_v):
+        """Set a specific microversion for the mock supports_microversion()."""
+        self.supports_microversion_mock.reset_mock(return_value=True)
+        self.supports_microversion_mock.side_effect = (
+            lambda _, v: api_versions.APIVersion(v)
+            <= api_versions.APIVersion(mock_v)
+        )
+
+
+class TestBackupCreate(TestBackup):
     volume = volume_fakes.create_one_volume()
     snapshot = volume_fakes.create_one_snapshot()
     new_backup = volume_fakes.create_one_backup(
-        attrs={'volume_id': volume.id, 'snapshot_id': snapshot.id})
+        attrs={'volume_id': volume.id, 'snapshot_id': snapshot.id}
+    )
 
     columns = (
-        'availability_zone',
-        'container',
-        'description',
         'id',
         'name',
-        'object_count',
-        'size',
-        'snapshot_id',
-        'status',
         'volume_id',
     )
     data = (
-        new_backup.availability_zone,
-        new_backup.container,
-        new_backup.description,
         new_backup.id,
         new_backup.name,
-        new_backup.object_count,
-        new_backup.size,
-        new_backup.snapshot_id,
-        new_backup.status,
         new_backup.volume_id,
     )
 
     def setUp(self):
         super().setUp()
 
-        self.volumes_mock.get.return_value = self.volume
-        self.snapshots_mock.get.return_value = self.snapshot
-        self.backups_mock.create.return_value = self.new_backup
+        self.sdk_client.find_volume.return_value = self.volume
+        self.sdk_client.find_snapshot.return_value = self.snapshot
+        self.sdk_client.create_backup.return_value = self.new_backup
 
         # Get the command object to test
         self.cmd = volume_backup.CreateVolumeBackup(self.app, None)
 
     def test_backup_create(self):
         arglist = [
-            "--name", self.new_backup.name,
-            "--description", self.new_backup.description,
-            "--container", self.new_backup.container,
+            "--name",
+            self.new_backup.name,
+            "--description",
+            self.new_backup.description,
+            "--container",
+            self.new_backup.container,
             "--force",
             "--incremental",
-            "--snapshot", self.new_backup.snapshot_id,
+            "--snapshot",
+            self.new_backup.snapshot_id,
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -103,8 +117,8 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.create.assert_called_with(
-            self.new_backup.volume_id,
+        self.sdk_client.create_backup.assert_called_with(
+            volume_id=self.new_backup.volume_id,
             container=self.new_backup.container,
             name=self.new_backup.name,
             description=self.new_backup.description,
@@ -116,12 +130,13 @@ class TestBackupCreate(TestBackup):
         self.assertEqual(self.data, data)
 
     def test_backup_create_with_properties(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.43')
+        self._set_mock_microversion('3.43')
 
         arglist = [
-            "--property", "foo=bar",
-            "--property", "wow=much-cool",
+            "--property",
+            "foo=bar",
+            "--property",
+            "wow=much-cool",
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -132,8 +147,8 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.create.assert_called_with(
-            self.new_backup.volume_id,
+        self.sdk_client.create_backup.assert_called_with(
+            volume_id=self.new_backup.volume_id,
             container=None,
             name=None,
             description=None,
@@ -145,12 +160,13 @@ class TestBackupCreate(TestBackup):
         self.assertEqual(self.data, data)
 
     def test_backup_create_with_properties_pre_v343(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.42')
+        self._set_mock_microversion('3.42')
 
         arglist = [
-            "--property", "foo=bar",
-            "--property", "wow=much-cool",
+            "--property",
+            "foo=bar",
+            "--property",
+            "wow=much-cool",
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -160,17 +176,16 @@ class TestBackupCreate(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
 
     def test_backup_create_with_availability_zone(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.51')
+        self._set_mock_microversion('3.51')
 
         arglist = [
-            "--availability-zone", "my-az",
+            "--availability-zone",
+            "my-az",
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -181,8 +196,8 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.create.assert_called_with(
-            self.new_backup.volume_id,
+        self.sdk_client.create_backup.assert_called_with(
+            volume_id=self.new_backup.volume_id,
             container=None,
             name=None,
             description=None,
@@ -194,11 +209,11 @@ class TestBackupCreate(TestBackup):
         self.assertEqual(self.data, data)
 
     def test_backup_create_with_availability_zone_pre_v351(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.50')
+        self._set_mock_microversion('3.50')
 
         arglist = [
-            "--availability-zone", "my-az",
+            "--availability-zone",
+            "my-az",
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -208,15 +223,16 @@ class TestBackupCreate(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.51 or greater", str(exc))
 
     def test_backup_create_without_name(self):
         arglist = [
-            "--description", self.new_backup.description,
-            "--container", self.new_backup.container,
+            "--description",
+            self.new_backup.description,
+            "--container",
+            self.new_backup.container,
             self.new_backup.volume_id,
         ]
         verifylist = [
@@ -228,8 +244,8 @@ class TestBackupCreate(TestBackup):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.create.assert_called_with(
-            self.new_backup.volume_id,
+        self.sdk_client.create_backup.assert_called_with(
+            volume_id=self.new_backup.volume_id,
             container=self.new_backup.container,
             name=None,
             description=self.new_backup.description,
@@ -241,32 +257,27 @@ class TestBackupCreate(TestBackup):
 
 
 class TestBackupDelete(TestBackup):
-
     backups = volume_fakes.create_backups(count=2)
 
     def setUp(self):
         super().setUp()
 
-        self.backups_mock.get = (
-            volume_fakes.get_backups(self.backups))
-        self.backups_mock.delete.return_value = None
+        self.sdk_client.find_backup = volume_fakes.get_backups(self.backups)
+        self.sdk_client.delete_backup.return_value = None
 
         # Get the command object to mock
         self.cmd = volume_backup.DeleteVolumeBackup(self.app, None)
 
     def test_backup_delete(self):
-        arglist = [
-            self.backups[0].id
-        ]
-        verifylist = [
-            ("backups", [self.backups[0].id])
-        ]
+        arglist = [self.backups[0].id]
+        verifylist = [("backups", [self.backups[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.delete.assert_called_with(
-            self.backups[0].id, False)
+        self.sdk_client.delete_backup.assert_called_with(
+            self.backups[0].id, ignore_missing=False, force=False
+        )
         self.assertIsNone(result)
 
     def test_backup_delete_with_force(self):
@@ -274,15 +285,14 @@ class TestBackupDelete(TestBackup):
             '--force',
             self.backups[0].id,
         ]
-        verifylist = [
-            ('force', True),
-            ("backups", [self.backups[0].id])
-        ]
+        verifylist = [('force', True), ("backups", [self.backups[0].id])]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
-        self.backups_mock.delete.assert_called_with(self.backups[0].id, True)
+        self.sdk_client.delete_backup.assert_called_with(
+            self.backups[0].id, ignore_missing=False, force=True
+        )
         self.assertIsNone(result)
 
     def test_delete_multiple_backups(self):
@@ -298,8 +308,8 @@ class TestBackupDelete(TestBackup):
 
         calls = []
         for b in self.backups:
-            calls.append(call(b.id, False))
-        self.backups_mock.delete.assert_has_calls(calls)
+            calls.append(call(b.id, ignore_missing=False, force=False))
+        self.sdk_client.delete_backup.assert_has_calls(calls)
         self.assertIsNone(result)
 
     def test_delete_multiple_backups_with_exception(self):
@@ -314,29 +324,31 @@ class TestBackupDelete(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         find_mock_result = [self.backups[0], exceptions.CommandError]
-        with mock.patch.object(utils, 'find_resource',
-                               side_effect=find_mock_result) as find_mock:
+        with mock.patch.object(
+            self.sdk_client, 'find_backup', side_effect=find_mock_result
+        ) as find_mock:
             try:
                 self.cmd.take_action(parsed_args)
                 self.fail('CommandError should be raised.')
             except exceptions.CommandError as e:
-                self.assertEqual('1 of 2 backups failed to delete.',
-                                 str(e))
+                self.assertEqual('1 of 2 backups failed to delete.', str(e))
 
-            find_mock.assert_any_call(self.backups_mock, self.backups[0].id)
-            find_mock.assert_any_call(self.backups_mock, 'unexist_backup')
+            find_mock.assert_any_call(self.backups[0].id, ignore_missing=False)
+            find_mock.assert_any_call('unexist_backup', ignore_missing=False)
 
             self.assertEqual(2, find_mock.call_count)
-            self.backups_mock.delete.assert_called_once_with(
-                self.backups[0].id, False
+            self.sdk_client.delete_backup.assert_called_once_with(
+                self.backups[0].id,
+                ignore_missing=False,
+                force=False,
             )
 
 
 class TestBackupList(TestBackup):
-
     volume = volume_fakes.create_one_volume()
     backups = volume_fakes.create_backups(
-        attrs={'volume_id': volume.name}, count=3)
+        attrs={'volume_id': volume.name}, count=3
+    )
 
     columns = (
         'ID',
@@ -353,33 +365,38 @@ class TestBackupList(TestBackup):
 
     data = []
     for b in backups:
-        data.append((
-            b.id,
-            b.name,
-            b.description,
-            b.status,
-            b.size,
-        ))
+        data.append(
+            (
+                b.id,
+                b.name,
+                b.description,
+                b.status,
+                b.size,
+            )
+        )
     data_long = []
     for b in backups:
-        data_long.append((
-            b.id,
-            b.name,
-            b.description,
-            b.status,
-            b.size,
-            b.availability_zone,
-            volume_backup.VolumeIdColumn(b.volume_id),
-            b.container,
-        ))
+        data_long.append(
+            (
+                b.id,
+                b.name,
+                b.description,
+                b.status,
+                b.size,
+                b.availability_zone,
+                volume_backup.VolumeIdColumn(b.volume_id),
+                b.container,
+            )
+        )
 
     def setUp(self):
         super().setUp()
 
-        self.volumes_mock.list.return_value = [self.volume]
-        self.backups_mock.list.return_value = self.backups
-        self.volumes_mock.get.return_value = self.volume
-        self.backups_mock.get.return_value = self.backups[0]
+        self.sdk_client.volumes.return_value = [self.volume]
+        self.sdk_client.backups.return_value = self.backups
+        self.sdk_client.find_volume.return_value = self.volume
+        self.sdk_client.find_backup.return_value = self.backups[0]
+
         # Get the command to test
         self.cmd = volume_backup.ListVolumeBackup(self.app, None)
 
@@ -398,16 +415,13 @@ class TestBackupList(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        search_opts = {
-            "name": None,
-            "status": None,
-            "volume_id": None,
-            'all_tenants': False,
-        }
-        self.volumes_mock.get.assert_not_called()
-        self.backups_mock.get.assert_not_called()
-        self.backups_mock.list.assert_called_with(
-            search_opts=search_opts,
+        self.sdk_client.find_volume.assert_not_called()
+        self.sdk_client.find_backup.assert_not_called()
+        self.sdk_client.backups.assert_called_with(
+            name=None,
+            status=None,
+            volume_id=None,
+            all_tenants=False,
             marker=None,
             limit=None,
         )
@@ -417,12 +431,17 @@ class TestBackupList(TestBackup):
     def test_backup_list_with_options(self):
         arglist = [
             "--long",
-            "--name", self.backups[0].name,
-            "--status", "error",
-            "--volume", self.volume.id,
-            "--marker", self.backups[0].id,
+            "--name",
+            self.backups[0].name,
+            "--status",
+            "error",
+            "--volume",
+            self.volume.id,
+            "--marker",
+            self.backups[0].id,
             "--all-projects",
-            "--limit", "3",
+            "--limit",
+            "3",
         ]
         verifylist = [
             ("long", True),
@@ -437,16 +456,17 @@ class TestBackupList(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
-        search_opts = {
-            "name": self.backups[0].name,
-            "status": "error",
-            "volume_id": self.volume.id,
-            'all_tenants': True,
-        }
-        self.volumes_mock.get.assert_called_once_with(self.volume.id)
-        self.backups_mock.get.assert_called_once_with(self.backups[0].id)
-        self.backups_mock.list.assert_called_with(
-            search_opts=search_opts,
+        self.sdk_client.find_volume.assert_called_once_with(
+            self.volume.id, ignore_missing=False
+        )
+        self.sdk_client.find_backup.assert_called_once_with(
+            self.backups[0].id, ignore_missing=False
+        )
+        self.sdk_client.backups.assert_called_with(
+            name=self.backups[0].name,
+            status="error",
+            volume_id=self.volume.id,
+            all_tenants=True,
             marker=self.backups[0].id,
             limit=3,
         )
@@ -455,7 +475,6 @@ class TestBackupList(TestBackup):
 
 
 class TestBackupRestore(TestBackup):
-
     volume = volume_fakes.create_one_volume()
     backup = volume_fakes.create_one_backup(
         attrs={'volume_id': volume.id},
@@ -464,22 +483,21 @@ class TestBackupRestore(TestBackup):
     def setUp(self):
         super().setUp()
 
-        self.backups_mock.get.return_value = self.backup
-        self.volumes_mock.get.return_value = self.volume
-        self.restores_mock.restore.return_value = (
+        self.sdk_client.find_backup.return_value = self.backup
+        self.sdk_client.find_volume.return_value = self.volume
+        self.sdk_client.restore_backup.return_value = (
             volume_fakes.create_one_volume(
                 {'id': self.volume['id']},
             )
         )
+
         # Get the command object to mock
         self.cmd = volume_backup.RestoreVolumeBackup(self.app, None)
 
     def test_backup_restore(self):
-        self.volumes_mock.get.side_effect = exceptions.CommandError()
-        self.volumes_mock.find.side_effect = exceptions.CommandError()
-        arglist = [
-            self.backup.id
-        ]
+        self.sdk_client.find_volume.side_effect = exceptions.CommandError()
+        # self.sdk_client.side_effect = exceptions.CommandError()
+        arglist = [self.backup.id]
         verifylist = [
             ("backup", self.backup.id),
             ("volume", None),
@@ -487,14 +505,16 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.restores_mock.restore.assert_called_with(
-            self.backup.id, None, None,
+        self.sdk_client.restore_backup.assert_called_with(
+            self.backup.id,
+            volume_id=None,
+            name=None,
         )
         self.assertIsNotNone(result)
 
     def test_backup_restore_with_volume(self):
-        self.volumes_mock.get.side_effect = exceptions.CommandError()
-        self.volumes_mock.find.side_effect = exceptions.CommandError()
+        self.sdk_client.find_volume.side_effect = exceptions.CommandError()
+        # self.volumes_mock.find.side_effect = exceptions.CommandError()
         arglist = [
             self.backup.id,
             self.backup.volume_id,
@@ -506,8 +526,10 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.restores_mock.restore.assert_called_with(
-            self.backup.id, None, self.backup.volume_id,
+        self.sdk_client.restore_backup.assert_called_with(
+            self.backup.id,
+            volume_id=None,
+            name=self.backup.volume_id,
         )
         self.assertIsNotNone(result)
 
@@ -525,8 +547,10 @@ class TestBackupRestore(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
-        self.restores_mock.restore.assert_called_with(
-            self.backup.id, self.volume.id, None,
+        self.sdk_client.restore_backup.assert_called_with(
+            self.backup.id,
+            volume_id=self.volume.id,
+            name=None,
         )
         self.assertIsNotNone(result)
 
@@ -548,8 +572,7 @@ class TestBackupRestore(TestBackup):
         )
 
 
-class TestBackupSet(TestBackup):
-
+class TestBackupSet(TestBackupLegacy):
     backup = volume_fakes.create_one_backup(
         attrs={'metadata': {'wow': 'cool'}},
     )
@@ -563,11 +586,13 @@ class TestBackupSet(TestBackup):
         self.cmd = volume_backup.SetVolumeBackup(self.app, None)
 
     def test_backup_set_name(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.9')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.9'
+        )
 
         arglist = [
-            '--name', 'new_name',
+            '--name',
+            'new_name',
             self.backup.id,
         ]
         verifylist = [
@@ -580,15 +605,18 @@ class TestBackupSet(TestBackup):
         # returns nothing
         result = self.cmd.take_action(parsed_args)
         self.backups_mock.update.assert_called_once_with(
-            self.backup.id, **{'name': 'new_name'})
+            self.backup.id, **{'name': 'new_name'}
+        )
         self.assertIsNone(result)
 
     def test_backup_set_name_pre_v39(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.8')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.8'
+        )
 
         arglist = [
-            '--name', 'new_name',
+            '--name',
+            'new_name',
             self.backup.id,
         ]
         verifylist = [
@@ -598,17 +626,18 @@ class TestBackupSet(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.9 or greater", str(exc))
 
     def test_backup_set_description(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.9')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.9'
+        )
 
         arglist = [
-            '--description', 'new_description',
+            '--description',
+            'new_description',
             self.backup.id,
         ]
         verifylist = [
@@ -621,21 +650,20 @@ class TestBackupSet(TestBackup):
         result = self.cmd.take_action(parsed_args)
 
         # Set expected values
-        kwargs = {
-            'description': 'new_description'
-        }
+        kwargs = {'description': 'new_description'}
         self.backups_mock.update.assert_called_once_with(
-            self.backup.id,
-            **kwargs
+            self.backup.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_backup_set_description_pre_v39(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.8')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.8'
+        )
 
         arglist = [
-            '--description', 'new_description',
+            '--description',
+            'new_description',
             self.backup.id,
         ]
         verifylist = [
@@ -646,52 +674,43 @@ class TestBackupSet(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.9 or greater", str(exc))
 
     def test_backup_set_state(self):
-        arglist = [
-            '--state', 'error',
-            self.backup.id
-        ]
-        verifylist = [
-            ('state', 'error'),
-            ('backup', self.backup.id)
-        ]
+        arglist = ['--state', 'error', self.backup.id]
+        verifylist = [('state', 'error'), ('backup', self.backup.id)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
         self.backups_mock.reset_state.assert_called_once_with(
-            self.backup.id, 'error')
+            self.backup.id, 'error'
+        )
         self.assertIsNone(result)
 
     def test_backup_set_state_failed(self):
         self.backups_mock.reset_state.side_effect = exceptions.CommandError()
-        arglist = [
-            '--state', 'error',
-            self.backup.id
-        ]
-        verifylist = [
-            ('state', 'error'),
-            ('backup', self.backup.id)
-        ]
+        arglist = ['--state', 'error', self.backup.id]
+        verifylist = [('state', 'error'), ('backup', self.backup.id)]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         try:
             self.cmd.take_action(parsed_args)
             self.fail('CommandError should be raised.')
         except exceptions.CommandError as e:
-            self.assertEqual('One or more of the set operations failed',
-                             str(e))
+            self.assertEqual(
+                'One or more of the set operations failed', str(e)
+            )
         self.backups_mock.reset_state.assert_called_with(
-            self.backup.id, 'error')
+            self.backup.id, 'error'
+        )
 
     def test_backup_set_no_property(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.43')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.43'
+        )
 
         arglist = [
             '--no-property',
@@ -710,14 +729,14 @@ class TestBackupSet(TestBackup):
             'metadata': {},
         }
         self.backups_mock.update.assert_called_once_with(
-            self.backup.id,
-            **kwargs
+            self.backup.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_backup_set_no_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.42')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.42'
+        )
 
         arglist = [
             '--no-property',
@@ -730,17 +749,18 @@ class TestBackupSet(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
 
     def test_backup_set_property(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.43')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.43'
+        )
 
         arglist = [
-            '--property', 'foo=bar',
+            '--property',
+            'foo=bar',
             self.backup.id,
         ]
         verifylist = [
@@ -756,17 +776,18 @@ class TestBackupSet(TestBackup):
             'metadata': {'wow': 'cool', 'foo': 'bar'},
         }
         self.backups_mock.update.assert_called_once_with(
-            self.backup.id,
-            **kwargs
+            self.backup.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_backup_set_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.42')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.42'
+        )
 
         arglist = [
-            '--property', 'foo=bar',
+            '--property',
+            'foo=bar',
             self.backup.id,
         ]
         verifylist = [
@@ -776,14 +797,12 @@ class TestBackupSet(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
 
 
-class TestBackupUnset(TestBackup):
-
+class TestBackupUnset(TestBackupLegacy):
     backup = volume_fakes.create_one_backup(
         attrs={'metadata': {'foo': 'bar'}},
     )
@@ -797,11 +816,13 @@ class TestBackupUnset(TestBackup):
         self.cmd = volume_backup.UnsetVolumeBackup(self.app, None)
 
     def test_backup_unset_property(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.43')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.43'
+        )
 
         arglist = [
-            '--property', 'foo',
+            '--property',
+            'foo',
             self.backup.id,
         ]
         verifylist = [
@@ -817,17 +838,18 @@ class TestBackupUnset(TestBackup):
             'metadata': {},
         }
         self.backups_mock.update.assert_called_once_with(
-            self.backup.id,
-            **kwargs
+            self.backup.id, **kwargs
         )
         self.assertIsNone(result)
 
     def test_backup_unset_property_pre_v343(self):
-        self.app.client_manager.volume.api_version = \
-            api_versions.APIVersion('3.42')
+        self.app.client_manager.volume.api_version = api_versions.APIVersion(
+            '3.42'
+        )
 
         arglist = [
-            '--property', 'foo',
+            '--property',
+            'foo',
             self.backup.id,
         ]
         verifylist = [
@@ -837,59 +859,73 @@ class TestBackupUnset(TestBackup):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         exc = self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args)
+            exceptions.CommandError, self.cmd.take_action, parsed_args
+        )
         self.assertIn("--os-volume-api-version 3.43 or greater", str(exc))
 
 
 class TestBackupShow(TestBackup):
-
     backup = volume_fakes.create_one_backup()
 
     columns = (
-        'availability_zone',
-        'container',
-        'description',
-        'id',
-        'name',
-        'object_count',
-        'size',
-        'snapshot_id',
-        'status',
-        'volume_id',
+        "availability_zone",
+        "container",
+        "created_at",
+        "data_timestamp",
+        "description",
+        "encryption_key_id",
+        "fail_reason",
+        "has_dependent_backups",
+        "id",
+        "is_incremental",
+        "metadata",
+        "name",
+        "object_count",
+        "project_id",
+        "size",
+        "snapshot_id",
+        "status",
+        "updated_at",
+        "user_id",
+        "volume_id",
     )
     data = (
         backup.availability_zone,
         backup.container,
+        backup.created_at,
+        backup.data_timestamp,
         backup.description,
+        backup.encryption_key_id,
+        backup.fail_reason,
+        backup.has_dependent_backups,
         backup.id,
+        backup.is_incremental,
+        backup.metadata,
         backup.name,
         backup.object_count,
+        backup.project_id,
         backup.size,
         backup.snapshot_id,
         backup.status,
+        backup.updated_at,
+        backup.user_id,
         backup.volume_id,
     )
 
     def setUp(self):
         super().setUp()
 
-        self.backups_mock.get.return_value = self.backup
+        self.sdk_client.get_backup.return_value = self.backup
         # Get the command object to test
         self.cmd = volume_backup.ShowVolumeBackup(self.app, None)
 
     def test_backup_show(self):
-        arglist = [
-            self.backup.id
-        ]
-        verifylist = [
-            ("backup", self.backup.id)
-        ]
+        arglist = [self.backup.id]
+        verifylist = [("backup", self.backup.id)]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        self.backups_mock.get.assert_called_with(self.backup.id)
+        self.sdk_client.get_backup.assert_called_with(self.backup.id)
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
